/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 56 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 479 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 964 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_DOUBLE;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_*().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1221 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1295 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1316 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1518 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1734 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 276 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 270
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 75
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  Expr* yy20;
  struct TrigEvent yy68;
  SrcList* yy93;
  ExprSpan yy114;
  struct type_def yy122;
  Select* yy149;
  int yy150;
  enum trim_side_mask yy203;
  ExprList* yy266;
  bool yy295;
  struct ExprList * yy343;
  TriggerStep* yy359;
  struct SrcList * yy380;
  struct Token yy429;
  struct LimitVal yy440;
  struct alter_args yy450;
  With* yy473;
  struct Expr * yy513;
  IdList* yy520;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             436
#define YYNRULE              315
#define YY_MAX_SHIFT         435
#define YY_MIN_SHIFTREDUCE   655
#define YY_MAX_SHIFTREDUCE   969
#define YY_MIN_REDUCE        970
#define YY_MAX_REDUCE        1284
#define YY_ERROR_ACTION      1285
#define YY_ACCEPT_ACTION     1286
#define YY_NO_ACTION         1287
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1581)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    65,   66,  292,  312,  836,  836,  846,  849,   63,   63,
 /*    10 */    64,   64,   64,   64,  305,   62,   62,   62,   62,   61,
 /*    20 */    61,   60,   60,   60,   59,  313,   64,   64,   64,   64,
 /*    30 */    57,   62,   62,   62,   62,   61,   61,   60,   60,   60,
 /*    40 */    59,  313,  959,  909,  959,  313,  960,  960,   65,   66,
 /*    50 */   292,  312,  836,  836,  846,  849,   63,   63,   64,   64,
 /*    60 */    64,   64,  366,   62,   62,   62,   62,   61,   61,   60,
 /*    70 */    60,   60,   59,  313, 1286,  435,    1,   65,   66,  292,
 /*    80 */   312,  836,  836,  846,  849,   63,   63,   64,   64,   64,
 /*    90 */    64,  221,   62,   62,   62,   62,   61,   61,   60,   60,
 /*   100 */    60,   59,  313,  961,  755,   52,  924,  925,  926,  927,
 /*   110 */   928,  929,  275,  932,  933,  934,  934,  935,  767,  130,
 /*   120 */    42,  130,   49,   50,  429,  837,  837,  847,  850,   51,
 /*   130 */    61,   61,   60,   60,   60,   59,  313,  901,  907,   67,
 /*   140 */   419,    4,   99,   99,  689,  806,  255,  314,  314,  383,
 /*   150 */   122,  731,  731,  902,  772,  773,  357,  315,  792,  315,
 /*   160 */   159,  113,  287,  903,  719,  400,  408,  290,  113,  189,
 /*   170 */   189,  720,  315,   58,   56,  188,  801, 1234, 1234,  403,
 /*   180 */   401,  387,   64,   64,   64,   64,  910,   62,   62,   62,
 /*   190 */    62,   61,   61,   60,   60,   60,   59,  313,  389,  421,
 /*   200 */   131,  113,  257,  256,  803,   62,   62,   62,   62,   61,
 /*   210 */    61,   60,   60,   60,   59,  313,  174,  186,  805,  805,
 /*   220 */   807,  808,  809,  810,  811,  427,  423,  821,  822,  823,
 /*   230 */   963,   21,   65,   66,  292,  312,  836,  836,  846,  849,
 /*   240 */    63,   63,   64,   64,   64,   64,  206,   62,   62,   62,
 /*   250 */    62,   61,   61,   60,   60,   60,   59,  313,   65,   66,
 /*   260 */   292,  312,  836,  836,  846,  849,   63,   63,   64,   64,
 /*   270 */    64,   64,  910,   62,   62,   62,   62,   61,   61,   60,
 /*   280 */    60,   60,   59,  313,   66,  292,  312,  836,  836,  846,
 /*   290 */   849,   63,   63,   64,   64,   64,   64,  912,   62,   62,
 /*   300 */    62,   62,   61,   61,   60,   60,   60,   59,  313,  357,
 /*   310 */   689,   60,   60,   60,   59,  313,   65,   66,  292,  312,
 /*   320 */   836,  836,  846,  849,   63,   63,   64,   64,   64,   64,
 /*   330 */   676,   62,   62,   62,   62,   61,   61,   60,   60,   60,
 /*   340 */    59,  313,  968,  357,  950,  291,  672,  950,  291,  881,
 /*   350 */   950,  880,    7,  950,  686,  684,  959,  686,  959,  341,
 /*   360 */   874,   65,   66,  292,  312,  836,  836,  846,  849,   63,
 /*   370 */    63,   64,   64,   64,   64,  429,   62,   62,   62,   62,
 /*   380 */    61,   61,   60,   60,   60,   59,  313,  766,  434,  434,
 /*   390 */   656,  317,  283,   82,   82,  151,  127,  257,  256,  246,
 /*   400 */   677,  377,  683,  376,  216,  221,   65,   66,  292,  312,
 /*   410 */   836,  836,  846,  849,   63,   63,   64,   64,   64,   64,
 /*   420 */   429,   62,   62,   62,   62,   61,   61,   60,   60,   60,
 /*   430 */    59,  313,  726,  209,  685,   71,  257,  256,   97,   97,
 /*   440 */    59,  313,   58,   56,  188,  827,  422,   53,   20,  190,
 /*   450 */   421,   65,   66,  292,  312,  836,  836,  846,  849,   63,
 /*   460 */    63,   64,   64,   64,   64,  901,   62,   62,   62,   62,
 /*   470 */    61,   61,   60,   60,   60,   59,  313,   58,   56,  188,
 /*   480 */   679,  902,  148,  171,  170,  121,  678,  286,  673,  673,
 /*   490 */   800,  903,  407,  391,  402,  421,   65,   66,  292,  312,
 /*   500 */   836,  836,  846,  849,   63,   63,   64,   64,   64,   64,
 /*   510 */   988,   62,   62,   62,   62,   61,   61,   60,   60,   60,
 /*   520 */    59,  313,   65,   66,  292,  312,  836,  836,  846,  849,
 /*   530 */    63,   63,   64,   64,   64,   64,  392,   62,   62,   62,
 /*   540 */    62,   61,   61,   60,   60,   60,   59,  313,   65,   66,
 /*   550 */   292,  312,  836,  836,  846,  849,   63,   63,   64,   64,
 /*   560 */    64,   64,  799,   62,   62,   62,   62,   61,   61,   60,
 /*   570 */    60,   60,   59,  313,   65,   66,  292,  312,  836,  836,
 /*   580 */   846,  849,   63,   63,   64,   64,   64,   64,  739,   62,
 /*   590 */    62,   62,   62,   61,   61,   60,   60,   60,   59,  313,
 /*   600 */    52,  728,  960,  960,  169,  168,   58,   56,  188,  697,
 /*   610 */   698,  699,  387,  795,  673,  673,  896,   49,   50,  113,
 /*   620 */   673,  673,  122,   69,   51,  319,   44,  806,  342,  236,
 /*   630 */   338,  945,  163,  806,  287,  419,    4, 1176,  130,  290,
 /*   640 */   806,  195,  314,  314,  945,  228,  384,  229,  817,  126,
 /*   650 */   228,  384,   47,  130,  318,  914,  320,  325,  801,  961,
 /*   660 */   754,  408,  947,  248,  801,  123,  672,  326,  323,  770,
 /*   670 */   771,  801,  181,  292,  312,  836,  836,  846,  849,   63,
 /*   680 */    63,   64,   64,   64,   64,  335,   62,   62,   62,   62,
 /*   690 */    61,   61,   60,   60,   60,   59,  313,  718,  718,  803,
 /*   700 */   805,  805,  807,  808,  809,  810,  805,  805,  807,  808,
 /*   710 */   809,  810,  194,  805,  805,  807,  808,  809,  810,  811,
 /*   720 */   427,  423,  671,  673,  673,  963,   21,   65,   66,  292,
 /*   730 */   312,  836,  836,  846,  849,   63,   63,   64,   64,   64,
 /*   740 */    64,   39,   62,   62,   62,   62,   61,   61,   60,   60,
 /*   750 */    60,   59,  313,   65,   55,  292,  312,  836,  836,  846,
 /*   760 */   849,   63,   63,   64,   64,   64,   64,   52,   62,   62,
 /*   770 */    62,   62,   61,   61,   60,   60,   60,   59,  313,  872,
 /*   780 */   130,  149,  695,  898,   49,   50,  113,  673,  673,  351,
 /*   790 */   184,   51,  308,  433,  753,  660,  432,  231,  284,   52,
 /*   800 */   355,  666,  419,    4,  795,  130,  130,  806,  671,  314,
 /*   810 */   314,  349,  295,  343,  884,  304,   49,   50,  740, 1003,
 /*   820 */   247,  348,  154,   51,  911,  308,   72,  429,  408, 1263,
 /*   830 */   273,  347,  911, 1263,  419,    4,  703,  799,  801,  806,
 /*   840 */   351,  314,  314,  356,  374,   24,   24,  884,  304,  704,
 /*   850 */   426,  333,  177,  753,  248,  289,  388,  201,   73,  294,
 /*   860 */   408,  229,  166,  262,  673,  673,  803,  799, 1263,  306,
 /*   870 */   801,  429,  362,  359,   23,   23,  255,  334,  241,  769,
 /*   880 */   805,  805,  807,  808,  809,  810,  811,  427,  423,   99,
 /*   890 */    99,  696,  963,   21,  229,  166,  262,  379,  803,    2,
 /*   900 */   199,  689,  421,  297,  429,  673,  673,  329,  207,  255,
 /*   910 */   768,  429,  805,  805,  807,  808,  809,  810,  811,  427,
 /*   920 */   423,   52,   99,   99,  963,   21,  403,  385,  417,   79,
 /*   930 */    79,  421,  429,  298,  240,  429,  426,  872,   49,   50,
 /*   940 */    58,   56,  188,  673,  673,   51,  421,  187,  186,  429,
 /*   950 */    99,   99,  381,   99,   99,  113,  419,    4,  273,  403,
 /*   960 */   390,  806,  799,  314,  314,  220,  382,   75,   75,  736,
 /*   970 */   301,   58,   56,  188,  735,  429,  239,  716,  716,  421,
 /*   980 */   238,  130,  408,  746,  429,  227,  421,  403,  399,  752,
 /*   990 */   403,  420,  801,   99,   99,   28,  878,  372,  370,  376,
 /*  1000 */   429,  394,   24,   24,  713,  795,  725,  421,  429,  113,
 /*  1010 */   421,  369,  713,  752,  429,  799,  300,  752,   84,   84,
 /*  1020 */   803,  247,  348,  406,  421,  429,   97,   97,  299,  328,
 /*  1030 */   403,  380,   99,   99,  805,  805,  807,  808,  809,  810,
 /*  1040 */   811,  427,  423,   85,   85,  429,  963,   21,  752,  429,
 /*  1050 */   421,  752,  429,  784,  429,  248,  413,  235,  176,  421,
 /*  1060 */   709,  752,  410,   24,   24,  113,  872,   26,   26,  309,
 /*  1070 */    99,   99,   24,   24,  958,  421,  429,  302,  429,  752,
 /*  1080 */   303,  310,  272,  421,  429,  346,  397,  429,  202,  421,
 /*  1090 */   429,  203,  429,  710,   86,   86,   87,   87,  429,  311,
 /*  1100 */   421,  904,   88,   88,  179,   27,   27,  395,   76,   76,
 /*  1110 */    78,   78,  753,  353,  429,  752,   89,   89,  429,  873,
 /*  1120 */   421,  429,  946,  429,  421,  429,  672,  421,  429,  421,
 /*  1130 */   429,  164,   90,   90,  741,  414,   91,   91,  113,   25,
 /*  1140 */    25,   92,   92,   93,   93,  752,   94,   94,   80,   80,
 /*  1150 */   429,  421,   48,  421,   46,  722,  429,  673,  673,  421,
 /*  1160 */   429,  804,  421,  429,  959,  421,  959,  421,   95,   95,
 /*  1170 */   177,  753,  429,  421,   96,   96,  429,  264,   81,   81,
 /*  1180 */   752,  118,  118,  429,  418,  721,  156,  113,  429,  421,
 /*  1190 */   119,  119,  266,  421,  120,  120,  421,  268,  421,  429,
 /*  1200 */   421,  103,  103,  421,  429,  421,   98,   98,  429,  175,
 /*  1210 */   429,  772,  773,  221,  429,  913,  876,   83,   83,   41,
 /*  1220 */   243,  429,  106,  106,  429,  421,  100,  100,  107,  107,
 /*  1230 */   271,  421,  105,  105,  898,  421,  429,  113,  421,  117,
 /*  1240 */   117,  429,  112,  112,  321,  736,  429,  421,  223,  429,
 /*  1250 */   735,  421,  429,  261,  111,  111,  234,  252,  421,  110,
 /*  1260 */   110,   10,  349,  421,  108,  108,  260,  109,  109,  429,
 /*  1270 */   102,  102,  429,  797,  421,  429,  197,  219,  918,  421,
 /*  1280 */   189,  189,  358,  421,  428,  421,  429,  104,  104,  421,
 /*  1290 */   101,  101,  387,   74,   74,  916,  421,  350,  867,  421,
 /*  1300 */   908,  219,  352,  906,   77,   77,  219,  336,  866,  917,
 /*  1310 */   367,  421,   41,  251,  223,  712,  421,  330,  711,   41,
 /*  1320 */   296,  421,   35,  331,  421,  687,  687,  421,  172,  173,
 /*  1330 */   733,  762,  702,  701,   43,  219,  870,  812,  812,  942,
 /*  1340 */   223,  332,  787,   12,  421,  337,  237,  421,  339,  180,
 /*  1350 */   421,  245,  893,  895,  354,  840,  892,  360,  361,  244,
 /*  1360 */   250,  421,  665,  254,  259,  682,  760,  798,  270,  742,
 /*  1370 */   409,  871,  274,    9,  280,  165,  674,  663,  662,  664,
 /*  1380 */   293,  155,  146,  114,  233,  124,  135,  137,  340,   39,
 /*  1390 */    30,  783,  139,  204,  141,  879,  365,  345,  242,  205,
 /*  1400 */   157,  212,  213,  363,  142,  214,  115,  253,  307,  150,
 /*  1410 */   794,  707,  373,  375,  692,  116,  693,  258,  378,  897,
 /*  1420 */   706,  681,  680,  393,   38,    8,  854,   45,  412,  416,
 /*  1430 */   222,  425,  931,   68,  398,   40,  396,  431,  943,  750,
 /*  1440 */   281,  288,    5,  282,  939,  230,  263,  232,   11,  751,
 /*  1450 */    70,  941,  265,  658,  316,  915,  749,  732,  278,  276,
 /*  1460 */   277,  267,  279,   13,  748,   29,  269,  191,  132,  322,
 /*  1470 */   192,  324,  193,  196,  133,  327,  877,  167,  134,  198,
 /*  1480 */   200,  793,  136,  128,  140,  723,  882,  344,  138,  219,
 /*  1490 */   143,  965,  891,  144,  147,   31,   32,  145,   33,   34,
 /*  1500 */   129,  890,  894,   22,  208,  210,  249,   14,  211,  158,
 /*  1510 */   668,  364,  260,  215,  152,   15,  368,   16,  172,  371,
 /*  1520 */    36,  705,  217,  173,  125,  730,   37,  826,  386,  761,
 /*  1530 */   824,  852,   17,  182,  734,    6,  218,  183,  185,  153,
 /*  1540 */   411,  865,  178,   43,  415,  756,   41,  853,   18,  851,
 /*  1550 */    19,  818,  900,  404,  899,  405,  922,  160,  161,  224,
 /*  1560 */   923,  856,  855,  162,  226,  825,  225,  430,  814,    3,
 /*  1570 */   424,  930,  813,   54,  285,  659,  669,  655, 1251,  972,
 /*  1580 */   841,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*    10 */    15,   16,   17,   18,   84,   20,   21,   22,   23,   24,
 /*    20 */    25,   26,   27,   28,   29,   30,   15,   16,   17,   18,
 /*    30 */    19,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*    40 */    29,   30,   47,  168,   49,   30,   49,   50,    5,    6,
 /*    50 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*    60 */    17,   18,    7,   20,   21,   22,   23,   24,   25,   26,
 /*    70 */    27,   28,   29,   30,  162,  163,  164,    5,    6,    7,
 /*    80 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*    90 */    18,   96,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   100 */    28,   29,   30,  106,  107,    7,  149,  150,  151,  152,
 /*   110 */   153,  154,  155,  156,  157,  158,  159,  160,  189,   45,
 /*   120 */    48,   45,   24,   25,  168,    9,   10,   11,   12,   31,
 /*   130 */    24,   25,   26,   27,   28,   29,   30,   35,  263,   67,
 /*   140 */    42,   43,  186,  187,   83,   47,   91,   49,   50,   97,
 /*   150 */   168,   99,  100,   51,  111,  112,  168,  175,  209,  177,
 /*   160 */   178,  212,  180,   61,   62,  209,   68,  185,  212,  210,
 /*   170 */   211,   69,  190,  244,  245,  246,   78,  101,  102,  223,
 /*   180 */   224,  222,   15,   16,   17,   18,  182,   20,   21,   22,
 /*   190 */    23,   24,   25,   26,   27,   28,   29,   30,  209,  243,
 /*   200 */   193,  212,  195,  196,  106,   20,   21,   22,   23,   24,
 /*   210 */    25,   26,   27,   28,   29,   30,  227,  228,  120,  121,
 /*   220 */   122,  123,  124,  125,  126,  127,  128,  129,  130,  131,
 /*   230 */   132,  133,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   240 */    13,   14,   15,   16,   17,   18,  258,   20,   21,   22,
 /*   250 */    23,   24,   25,   26,   27,   28,   29,   30,    5,    6,
 /*   260 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   270 */    17,   18,  268,   20,   21,   22,   23,   24,   25,   26,
 /*   280 */    27,   28,   29,   30,    6,    7,    8,    9,   10,   11,
 /*   290 */    12,   13,   14,   15,   16,   17,   18,   44,   20,   21,
 /*   300 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  168,
 /*   310 */    83,   26,   27,   28,   29,   30,    5,    6,    7,    8,
 /*   320 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   330 */   186,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   340 */    29,   30,  179,  168,  184,  185,  183,  184,  185,   54,
 /*   350 */   190,   56,   43,  190,  194,   44,   47,  194,   49,   64,
 /*   360 */   186,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   370 */    14,   15,   16,   17,   18,  168,   20,   21,   22,   23,
 /*   380 */    24,   25,   26,   27,   28,   29,   30,  189,  165,  166,
 /*   390 */     1,    2,  169,  186,  187,  193,  173,  195,  196,  258,
 /*   400 */    44,   79,   80,   81,   82,   96,    5,    6,    7,    8,
 /*   410 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   420 */   168,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   430 */    29,   30,  209,  258,  193,  212,  195,  196,  186,  187,
 /*   440 */    29,   30,  244,  245,  246,   44,  239,  240,  241,   43,
 /*   450 */   243,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   460 */    14,   15,   16,   17,   18,   35,   20,   21,   22,   23,
 /*   470 */    24,   25,   26,   27,   28,   29,   30,  244,  245,  246,
 /*   480 */   186,   51,   43,  260,  261,  262,  186,  264,   49,   50,
 /*   490 */    44,   61,   62,    7,  242,  243,    5,    6,    7,    8,
 /*   500 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   510 */   104,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   520 */    29,   30,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   530 */    13,   14,   15,   16,   17,   18,   50,   20,   21,   22,
 /*   540 */    23,   24,   25,   26,   27,   28,   29,   30,    5,    6,
 /*   550 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   560 */    17,   18,  168,   20,   21,   22,   23,   24,   25,   26,
 /*   570 */    27,   28,   29,   30,    5,    6,    7,    8,    9,   10,
 /*   580 */    11,   12,   13,   14,   15,   16,   17,   18,  226,   20,
 /*   590 */    21,   22,   23,   24,   25,   26,   27,   28,   29,   30,
 /*   600 */     7,  211,   49,   50,   24,   25,  244,  245,  246,   87,
 /*   610 */    88,   89,  222,   69,   49,   50,  209,   24,   25,  212,
 /*   620 */    49,   50,  168,   43,   31,  265,  135,   47,  234,   85,
 /*   630 */    86,  177,  178,   47,  180,   42,   43,   44,   45,  185,
 /*   640 */    47,   76,   49,   50,  190,  101,  102,   76,  105,   53,
 /*   650 */   101,  102,  135,   45,   79,   80,   81,  235,   78,  106,
 /*   660 */   107,   68,  179,  119,   78,   96,  183,   71,   93,   73,
 /*   670 */    74,   78,   48,    7,    8,    9,   10,   11,   12,   13,
 /*   680 */    14,   15,   16,   17,   18,   77,   20,   21,   22,   23,
 /*   690 */    24,   25,   26,   27,   28,   29,   30,  205,  206,  106,
 /*   700 */   120,  121,  122,  123,  124,  125,  120,  121,  122,  123,
 /*   710 */   124,  125,  147,  120,  121,  122,  123,  124,  125,  126,
 /*   720 */   127,  128,  182,   49,   50,  132,  133,    5,    6,    7,
 /*   730 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   740 */    18,  117,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   750 */    28,   29,   30,    5,    6,    7,    8,    9,   10,   11,
 /*   760 */    12,   13,   14,   15,   16,   17,   18,    7,   20,   21,
 /*   770 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  168,
 /*   780 */    45,   43,  197,  209,   24,   25,  212,   49,   50,  168,
 /*   790 */    44,   31,    7,   32,   48,   34,   35,   36,   37,    7,
 /*   800 */     7,   40,   42,   43,   69,   45,   45,   47,  268,   49,
 /*   810 */    50,  237,  201,   85,   86,   30,   24,   25,   26,    1,
 /*   820 */    85,   86,  148,   31,  194,    7,  252,  168,   68,   44,
 /*   830 */   168,  257,  202,   48,   42,   43,   57,  168,   78,   47,
 /*   840 */   168,   49,   50,   50,   65,  186,  187,  119,   30,   70,
 /*   850 */   182,   90,  106,  107,  119,   94,  168,  236,   43,  200,
 /*   860 */    68,   76,   77,   78,   49,   50,  106,  168,   83,   90,
 /*   870 */    78,  168,  250,  251,  186,  187,   91,  116,   39,  183,
 /*   880 */   120,  121,  122,  123,  124,  125,  126,  127,  128,  186,
 /*   890 */   187,  197,  132,  133,   76,   77,   78,   26,  106,   43,
 /*   900 */   139,   83,  243,  234,  168,   49,   50,  146,  236,   91,
 /*   910 */   183,  168,  120,  121,  122,  123,  124,  125,  126,  127,
 /*   920 */   128,    7,  186,  187,  132,  133,  223,  224,  266,  186,
 /*   930 */   187,  243,  168,  234,   95,  168,  268,  168,   24,   25,
 /*   940 */   244,  245,  246,   49,   50,   31,  243,  227,  228,  168,
 /*   950 */   186,  187,  209,  186,  187,  212,   42,   43,  168,  223,
 /*   960 */   224,   47,  168,   49,   50,  226,  223,  186,  187,   98,
 /*   970 */   201,  244,  245,  246,  103,  168,  137,  205,  206,  243,
 /*   980 */   141,   45,   68,  229,  168,  215,  243,  223,  224,  168,
 /*   990 */   223,  224,   78,  186,  187,  225,   60,   79,   80,   81,
 /*  1000 */   168,  233,  186,  187,  194,   69,  209,  243,  168,  212,
 /*  1010 */   243,   93,  202,  168,  168,  168,  200,  168,  186,  187,
 /*  1020 */   106,   85,   86,  206,  243,  168,  186,  187,  234,  208,
 /*  1030 */   223,  224,  186,  187,  120,  121,  122,  123,  124,  125,
 /*  1040 */   126,  127,  128,  186,  187,  168,  132,  133,  168,  168,
 /*  1050 */   243,  168,  168,  208,  168,  119,  266,  208,  233,  243,
 /*  1060 */    59,  168,  209,  186,  187,  212,  168,  186,  187,  223,
 /*  1070 */   186,  187,  186,  187,   48,  243,  168,  200,  168,  168,
 /*  1080 */   199,  234,  242,  243,  168,  254,  200,  168,  208,  243,
 /*  1090 */   168,  208,  168,   92,  186,  187,  186,  187,  168,  201,
 /*  1100 */   243,  208,  186,  187,  253,  186,  187,  223,  186,  187,
 /*  1110 */   186,  187,   48,  168,  168,  168,  186,  187,  168,  208,
 /*  1120 */   243,  168,  179,  168,  243,  168,  183,  243,  168,  243,
 /*  1130 */   168,  105,  186,  187,   26,  209,  186,  187,  212,  186,
 /*  1140 */   187,  186,  187,  186,  187,  168,  186,  187,  186,  187,
 /*  1150 */   168,  243,  134,  243,  136,  208,  168,   49,   50,  243,
 /*  1160 */   168,  168,  243,  168,   47,  243,   49,  243,  186,  187,
 /*  1170 */   106,  107,  168,  243,  186,  187,  168,  226,  186,  187,
 /*  1180 */   168,  186,  187,  168,  209,  208,  213,  212,  168,  243,
 /*  1190 */   186,  187,  226,  243,  186,  187,  243,  226,  243,  168,
 /*  1200 */   243,  186,  187,  243,  168,  243,  186,  187,  168,  168,
 /*  1210 */   168,  111,  112,   96,  168,   44,   44,  186,  187,   48,
 /*  1220 */   208,  168,  186,  187,  168,  243,  186,  187,  186,  187,
 /*  1230 */   168,  243,  186,  187,  209,  243,  168,  212,  243,  186,
 /*  1240 */   187,  168,  186,  187,   44,   98,  168,  243,   48,  168,
 /*  1250 */   103,  243,  168,   78,  186,  187,  168,   39,  243,  186,
 /*  1260 */   187,  214,  237,  243,  186,  187,   91,  186,  187,  168,
 /*  1270 */   186,  187,  168,   44,  243,  168,  104,   48,  168,  243,
 /*  1280 */   210,  211,  257,  243,    7,  243,  168,  186,  187,  243,
 /*  1290 */   186,  187,  222,  186,  187,  168,  243,   44,   80,  243,
 /*  1300 */   168,   48,   44,  168,  186,  187,   48,  237,   44,  168,
 /*  1310 */    44,  243,   48,   95,   48,   44,  243,  168,   44,   48,
 /*  1320 */   168,  243,   48,  168,  243,   49,   50,  243,   85,   86,
 /*  1330 */    44,   44,   77,   78,   48,   48,   44,   49,   50,   44,
 /*  1340 */    48,  168,  217,   48,  243,  230,  230,  243,  168,  168,
 /*  1350 */   243,  259,  168,  217,  259,   78,  168,  168,  168,  141,
 /*  1360 */   168,  243,  168,  168,  168,  189,  168,  168,  230,  168,
 /*  1370 */   249,  168,  168,  214,  216,  214,  168,  168,  168,  168,
 /*  1380 */     9,   43,   43,  192,  191,    5,  238,  204,   41,  117,
 /*  1390 */   134,  217,  207,  207,  207,  256,   41,  143,  255,  174,
 /*  1400 */   238,  174,  174,  191,  207,  174,  192,  191,   63,  204,
 /*  1410 */   204,  198,   84,   84,  195,  192,  196,  191,   84,  217,
 /*  1420 */   198,  188,  188,  109,   84,   43,  247,  134,  191,  191,
 /*  1430 */   248,   43,  267,  115,  110,  114,  113,   46,  176,  232,
 /*  1440 */    45,  171,   43,  170,   36,  167,  231,  167,  181,  232,
 /*  1450 */   181,  172,  231,    4,    3,   66,  232,  221,  218,  220,
 /*  1460 */   219,  231,  217,   43,  232,   43,  231,   82,   43,   66,
 /*  1470 */    76,   81,   38,   76,   39,   94,   44,   14,   39,   43,
 /*  1480 */   138,  102,  118,   90,   84,   42,  142,  144,  105,   48,
 /*  1490 */   142,  145,    1,   84,  118,   14,   14,  105,   14,   14,
 /*  1500 */    90,    1,   50,  140,  108,  104,  137,   43,   84,   96,
 /*  1510 */    42,    7,   91,   82,   43,   43,   66,   43,   85,   66,
 /*  1520 */    43,   52,   66,   86,   58,   98,   48,   44,   48,   50,
 /*  1530 */    44,   44,   43,  104,   44,   43,  108,   44,   44,   43,
 /*  1540 */    96,   44,   43,   48,   96,  107,   48,   44,  108,   44,
 /*  1550 */   108,  105,   44,   47,   44,   48,   44,   43,   43,   48,
 /*  1560 */    44,   60,   44,   43,  104,   44,   43,   14,   44,   43,
 /*  1570 */   125,   44,   44,   43,   38,   33,   47,    1,    0,  269,
 /*  1580 */    78,
};
#define YY_SHIFT_USE_DFLT (1581)
#define YY_SHIFT_COUNT    (435)
#define YY_SHIFT_MIN      (-70)
#define YY_SHIFT_MAX      (1578)
static const short yy_shift_ofst[] = {
 /*     0 */   389,  761,  593,   98,  760,  571,  914,  914,  914,  914,
 /*    10 */   914,  818,  571,  914,  914,  914,  914,  914,  914,  914,
 /*    20 */   914,  914,  735,   -5,   43,   43,  227,  227,  792,  914,
 /*    30 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    40 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    50 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    60 */   914,  914,  914,  914,  914,  914,  914,  914,  914,  914,
 /*    70 */   785,  544,  936,   76,   72,  253,  311,  356,  401,  446,
 /*    80 */   491,  517,  543,  569,  722,  722,  722,  722,  722,  722,
 /*    90 */   722,  722,  722,  722,  722,  722,  722,  722,  722,  722,
 /*   100 */   748,  722,  278,  666,  666,   11,  167,  167,  167,  185,
 /*   110 */   106,  285,  411,  549,  -70,  -70,  -70,   15, 1581, 1581,
 /*   120 */  1581,  -43,  -43,  -43,  102,  102,  565, 1218,  439,  439,
 /*   130 */   674,   55,  894,  894,  894,  608,  894,  894,  894,  894,
 /*   140 */   894,  894,  894,  894,  894,  894,  894,  894,  894,  894,
 /*   150 */   894,   55,  894,  894,  894,  894,  549,   74,   74,   61,
 /*   160 */    74,   74,   74,   61, 1581, 1581,  580,  586,  586,  586,
 /*   170 */   575,  596,  779,  779,  746,  309,   -3,  553,  430,  728,
 /*   180 */   295,  738, 1108, 1117, 1117, 1117,  815, 1064,  856,   52,
 /*   190 */   871,  894,  894,  894,  894,  894,  894,  894,  894,  894,
 /*   200 */   894,  624,  486,  486,  894,  894,  793,  624,  894,  793,
 /*   210 */   894,  894,  894,  894,  894,  894,  894, 1100,  894,  894,
 /*   220 */   486,  894, 1018,  894,  894, 1147,  894, 1026, 1147,  894,
 /*   230 */   894,  894,  894, 1371, 1338, 1339, 1380, 1272, 1347, 1347,
 /*   240 */  1347, 1347, 1256, 1254, 1355, 1272, 1339, 1380, 1380, 1355,
 /*   250 */  1338, 1355, 1355, 1371, 1338, 1345, 1328, 1329, 1371, 1338,
 /*   260 */  1345, 1334, 1334, 1314, 1340, 1314, 1340, 1314, 1340, 1314,
 /*   270 */  1340, 1382, 1293, 1338, 1338, 1388, 1318, 1324, 1321, 1323,
 /*   280 */  1272, 1391, 1395, 1399, 1408, 1408, 1581, 1581, 1581,  839,
 /*   290 */   918,  322,  116,  522, 1171, 1200, 1172, 1229, 1253, 1258,
 /*   300 */  1264, 1266, 1271, 1274, 1276, 1243, 1255, 1001, 1175, 1286,
 /*   310 */  1287, 1292, 1277, 1288,  406, 1295, 1449, 1451, 1389, 1420,
 /*   320 */  1422, 1385, 1425, 1403, 1394, 1390, 1434, 1397, 1381, 1435,
 /*   330 */  1432, 1436, 1463, 1342, 1439, 1379, 1364, 1393, 1383, 1400,
 /*   340 */  1443, 1344, 1441, 1348, 1346, 1343, 1409, 1491, 1392, 1376,
 /*   350 */  1481, 1482, 1484, 1485, 1410, 1452, 1396, 1401, 1500, 1363,
 /*   360 */  1464, 1424, 1369, 1413, 1468, 1504, 1421, 1431, 1471, 1450,
 /*   370 */  1472, 1474, 1453, 1433, 1469, 1437, 1477, 1456, 1466, 1483,
 /*   380 */  1486, 1487, 1478, 1427, 1489, 1490, 1492, 1480, 1429, 1493,
 /*   390 */  1494, 1479, 1428, 1496, 1438, 1495, 1440, 1498, 1442, 1497,
 /*   400 */  1503, 1505, 1446, 1495, 1508, 1506, 1507, 1510, 1499, 1501,
 /*   410 */  1512, 1514, 1444, 1511, 1516, 1515, 1448, 1511, 1518, 1520,
 /*   420 */  1521, 1523, 1524, 1526, 1527, 1445, 1528, 1530, 1502, 1460,
 /*   430 */  1529, 1553, 1536, 1542, 1576, 1578,
};
#define YY_REDUCE_USE_DFLT (-126)
#define YY_REDUCE_COUNT (288)
#define YY_REDUCE_MIN   (-125)
#define YY_REDUCE_MAX   (1280)
static const short yy_reduce_ofst[] = {
 /*     0 */   -88,  223,  -44,  207,  743,  -18,  703,  736,  764,  767,
 /*    10 */   807,  163,  454,  659,  816,  877,  881,  846,  884,  886,
 /*    20 */   252,  840,  574,  362,  -71,  198,  696,  727,  688,  781,
 /*    30 */   832,  857,  908,  910,  916,  919,  922,  924,  930,  946,
 /*    40 */   950,  953,  955,  957,  960,  962,  982,  988,  992,  995,
 /*    50 */  1004, 1008, 1015, 1020, 1031, 1036, 1040, 1042, 1046, 1053,
 /*    60 */  1056, 1068, 1073, 1078, 1081, 1084, 1101, 1104, 1107, 1118,
 /*    70 */   160, 1070, 1025,  -11,  233,  233,  233,  233,  233,  233,
 /*    80 */   233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
 /*    90 */   233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
 /*   100 */   233,  233,  233,  233,  233,  233,  233,  233,  233,  233,
 /*   110 */   233,  233,  233,  -41,    7,  202,  241,  233,  233,  233,
 /*   120 */   233,    4,  540,  668,  492,  772, -125,  622,  621,  672,
 /*   130 */   662,  630,  611,  821,  845,  -51,  849,  880,  883,  893,
 /*   140 */   911,  947,  977,  394, 1012,  -12,  669,  141,  699,  794,
 /*   150 */   175,  810,  769,  847,  790,  898,  390,  407,  797,  483,
 /*   160 */   853,  926,  975,  943,  720,  770,  144,  174,  294,  300,
 /*   170 */   360,  422,  585,  694,  754,  739,  768,  825,  817,  831,
 /*   180 */   851,  945,  993,  951,  966,  971, 1041,  754, 1062,  973,
 /*   190 */  1047, 1088, 1110, 1127, 1132, 1135, 1141, 1149, 1152, 1155,
 /*   200 */  1173, 1125, 1115, 1116, 1180, 1181, 1092, 1136, 1184, 1095,
 /*   210 */  1188, 1189, 1190, 1192, 1194, 1195, 1196, 1176, 1198, 1199,
 /*   220 */  1138, 1201, 1121, 1203, 1204, 1159,  993, 1158, 1161, 1208,
 /*   230 */  1209, 1210, 1211, 1191, 1193, 1148, 1183, 1174, 1185, 1186,
 /*   240 */  1187, 1197, 1139, 1143, 1225, 1202, 1162, 1205, 1206, 1227,
 /*   250 */  1212, 1228, 1231, 1214, 1216, 1213, 1219, 1220, 1223, 1226,
 /*   260 */  1222, 1233, 1234, 1207, 1215, 1217, 1221, 1224, 1230, 1232,
 /*   270 */  1235, 1179, 1182, 1237, 1238, 1165, 1236, 1239, 1241, 1240,
 /*   280 */  1245, 1262, 1270, 1273, 1278, 1280, 1267, 1269, 1279,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1252, 1234, 1234, 1285, 1234,  990, 1176, 1176, 1176, 1176,
 /*    10 */  1176,  990,  990, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*    20 */  1134, 1134, 1234, 1058, 1089, 1089, 1003, 1003, 1285, 1285,
 /*    30 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*    40 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*    50 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*    60 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*    70 */   990, 1285, 1234, 1062, 1095, 1285, 1285, 1285, 1177, 1178,
 /*    80 */  1285, 1285, 1131, 1285, 1204, 1106, 1105, 1104, 1103, 1072,
 /*    90 */  1101, 1093, 1097, 1177, 1173, 1174, 1172, 1135, 1130, 1178,
 /*   100 */  1285, 1096, 1144, 1157, 1143, 1153, 1163, 1154, 1146, 1145,
 /*   110 */  1147, 1148, 1149, 1285, 1009, 1009, 1009, 1150, 1160, 1159,
 /*   120 */  1158, 1285, 1285, 1285, 1285, 1285, 1285, 1183, 1285, 1285,
 /*   130 */  1285, 1029, 1285, 1285, 1285, 1234, 1285, 1285, 1285, 1285,
 /*   140 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   150 */  1285, 1029, 1285, 1285, 1285, 1285, 1285, 1234, 1234, 1003,
 /*   160 */  1234, 1234, 1234, 1003, 1062, 1053, 1285, 1285, 1285, 1285,
 /*   170 */  1285, 1285, 1285, 1285, 1285, 1058, 1285, 1285, 1285, 1285,
 /*   180 */  1198, 1285, 1285, 1058, 1058, 1058, 1285, 1060, 1285, 1042,
 /*   190 */  1052, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   200 */  1285, 1100, 1074, 1074, 1285, 1285, 1282, 1100, 1285, 1282,
 /*   210 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1089, 1285, 1285,
 /*   220 */  1074, 1285, 1175, 1285, 1285, 1052, 1285, 1059, 1052, 1285,
 /*   230 */  1285, 1285, 1285, 1015, 1184, 1111, 1032, 1100, 1039, 1039,
 /*   240 */  1039, 1039, 1203, 1202,  982, 1100, 1111, 1032, 1032,  982,
 /*   250 */  1184,  982,  982, 1015, 1184, 1023, 1006, 1005, 1015, 1184,
 /*   260 */  1023, 1030, 1030, 1078, 1073, 1078, 1073, 1078, 1073, 1078,
 /*   270 */  1073, 1179, 1285, 1184, 1184, 1285, 1094, 1079, 1092, 1090,
 /*   280 */  1100, 1285, 1259, 1285, 1255, 1255, 1266, 1266,  985, 1285,
 /*   290 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   300 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   310 */  1285, 1285, 1285, 1285, 1117, 1285, 1285,  972, 1285, 1285,
 /*   320 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1220, 1285,
 /*   330 */  1285, 1190, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   340 */  1285, 1285, 1201, 1200, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   350 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1281, 1285, 1285,
 /*   360 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   370 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   380 */  1285, 1285, 1285, 1044, 1285, 1285, 1285, 1272, 1285, 1285,
 /*   390 */  1285, 1285, 1285, 1285, 1285, 1091, 1285, 1080, 1285, 1285,
 /*   400 */  1285, 1285, 1285, 1279, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   410 */  1285, 1285, 1285, 1236, 1285, 1285, 1285, 1235, 1285, 1285,
 /*   420 */  1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285, 1285,
 /*   430 */  1285, 1285,  976, 1285, 1285, 1285,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   49,  /*      QUERY => ID */
   49,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   49,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   49,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   49,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*       WITH => nothing */
   49,  /*     ENGINE => ID */
    0,  /*     STRING => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   49,  /*      ABORT => ID */
   49,  /*     ACTION => ID */
   49,  /*        ADD => ID */
   49,  /*      AFTER => ID */
   49,  /* AUTOINCREMENT => ID */
   49,  /*     BEFORE => ID */
   49,  /*    CASCADE => ID */
   49,  /*   CONFLICT => ID */
   49,  /*   DEFERRED => ID */
   49,  /*        END => ID */
   49,  /*       FAIL => ID */
   49,  /*     IGNORE => ID */
   49,  /*  INITIALLY => ID */
   49,  /*    INSTEAD => ID */
   49,  /*         NO => ID */
   49,  /*        KEY => ID */
   49,  /*     OFFSET => ID */
   49,  /*      RAISE => ID */
   49,  /*    REPLACE => ID */
   49,  /*   RESTRICT => ID */
   49,  /*     RENAME => ID */
   49,  /*   CTIME_KW => ID */
   49,  /*     ENABLE => ID */
   49,  /*    DISABLE => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "WITH",          "ENGINE",        "STRING",      
  "COMMA",         "ID",            "INDEXED",       "ABORT",       
  "ACTION",        "ADD",           "AFTER",         "AUTOINCREMENT",
  "BEFORE",        "CASCADE",       "CONFLICT",      "DEFERRED",    
  "END",           "FAIL",          "IGNORE",        "INITIALLY",   
  "INSTEAD",       "NO",            "KEY",           "OFFSET",      
  "RAISE",         "REPLACE",       "RESTRICT",      "RENAME",      
  "CTIME_KW",      "ENABLE",        "DISABLE",       "ANY",         
  "CONSTRAINT",    "DEFAULT",       "NULL",          "PRIMARY",     
  "UNIQUE",        "CHECK",         "REFERENCES",    "AUTOINCR",    
  "ON",            "UPDATE",        "DELETE",        "SIMPLE",      
  "PARTIAL",       "FULL",          "SET",           "DEFERRABLE",  
  "IMMEDIATE",     "FOREIGN",       "DROP",          "VIEW",        
  "AS",            "UNION",         "ALL",           "EXCEPT",      
  "INTERSECT",     "SELECT",        "VALUES",        "DISTINCT",    
  "DOT",           "FROM",          "JOIN_KW",       "JOIN",        
  "BY",            "USING",         "ORDER",         "ASC",         
  "DESC",          "GROUP",         "HAVING",        "LIMIT",       
  "TRUNCATE",      "WHERE",         "INTO",          "INSERT",      
  "FLOAT",         "BLOB",          "FALSE",         "TRUE",        
  "UNKNOWN",       "INTEGER",       "VARIABLE",      "CAST",        
  "TRIM",          "LEADING",       "TRAILING",      "BOTH",        
  "CHAR",          "CASE",          "WHEN",          "THEN",        
  "ELSE",          "INDEX",         "SESSION",       "PRAGMA",      
  "BEGIN",         "TRIGGER",       "OF",            "FOR",         
  "EACH",          "ROW",           "ALTER",         "COLUMN",      
  "RECURSIVE",     "TEXT",          "STRING_KW",     "SCALAR",      
  "BOOL",          "BOOLEAN",       "VARBINARY",     "VARCHAR",     
  "NUMBER",        "DOUBLE",        "INT",           "INTEGER_KW",  
  "UNSIGNED",      "error",         "input",         "ecmd",        
  "explain",       "cmdx",          "cmd",           "savepoint_opt",
  "nm",            "create_table",  "create_table_args",  "with_opts",   
  "create_table_end",  "createkw",      "ifnotexists",   "columnlist",  
  "engine_opts",   "tcons",         "column_def",    "create_column_end",
  "column_name_and_type",  "carglist",      "typedef",       "autoinc",     
  "ccons",         "cconsname",     "term",          "expr",        
  "onconf",        "sortorder",     "check_constraint_def",  "eidlist_opt", 
  "matcharg",      "refargs",       "defer_subclause",  "refact_update",
  "refact_delete",  "refact",        "init_deferred_pred_opt",  "col_list_with_autoinc",
  "sortlist",      "eidlist",       "defer_subclause_opt",  "index_onconf",
  "orconf",        "resolvetype",   "raisetype",     "ifexists",    
  "fullname",      "select",        "selectnowith",  "oneselect",   
  "with",          "multiselect_op",  "distinct",      "selcollist",  
  "from",          "where_opt",     "groupby_opt",   "having_opt",  
  "orderby_opt",   "limit_opt",     "values",        "nexprlist",   
  "exprlist",      "sclp",          "as",            "seltablist",  
  "stl_prefix",    "joinop",        "indexed_opt",   "on_opt",      
  "using_opt",     "join_nm",       "idlist",        "enable",      
  "setlist",       "insert_cmd",    "idlist_opt",    "trim_operands",
  "trim_from_clause",  "trim_specification",  "expr_optional",  "type_func",   
  "likeop",        "between_op",    "in_op",         "paren_exprlist",
  "case_exprlist",  "case_else",     "uniqueflag",    "trigger_decl",
  "trigger_cmd_list",  "trigger_time",  "trigger_event",  "foreach_clause",
  "when_clause",   "trigger_cmd",   "trnm",          "tridxby",     
  "alter_table_start",  "alter_add_constraint",  "alter_add_column",  "column_name", 
  "alter_column_def",  "unique_spec",   "wqlist",        "char_len",    
  "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "engine_opts ::= ENGINE EQ STRING",
 /*  15 */ "create_table_end ::=",
 /*  16 */ "column_name_and_type ::= nm typedef",
 /*  17 */ "create_column_end ::= autoinc",
 /*  18 */ "nm ::= ID|INDEXED",
 /*  19 */ "cconsname ::= CONSTRAINT nm",
 /*  20 */ "cconsname ::=",
 /*  21 */ "ccons ::= DEFAULT term",
 /*  22 */ "ccons ::= DEFAULT LP expr RP",
 /*  23 */ "ccons ::= DEFAULT PLUS term",
 /*  24 */ "ccons ::= DEFAULT MINUS term",
 /*  25 */ "ccons ::= NULL onconf",
 /*  26 */ "ccons ::= NOT NULL onconf",
 /*  27 */ "ccons ::= cconsname PRIMARY KEY sortorder",
 /*  28 */ "ccons ::= cconsname UNIQUE",
 /*  29 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  30 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  31 */ "ccons ::= defer_subclause",
 /*  32 */ "ccons ::= COLLATE ID|INDEXED",
 /*  33 */ "autoinc ::=",
 /*  34 */ "autoinc ::= AUTOINCR",
 /*  35 */ "refargs ::= refact_update",
 /*  36 */ "refargs ::= refact_delete",
 /*  37 */ "refargs ::= refact_delete refact_update",
 /*  38 */ "refargs ::= refact_update refact_delete",
 /*  39 */ "refargs ::=",
 /*  40 */ "refact_update ::= ON UPDATE refact",
 /*  41 */ "refact_delete ::= ON DELETE refact",
 /*  42 */ "matcharg ::= MATCH SIMPLE",
 /*  43 */ "matcharg ::= MATCH PARTIAL",
 /*  44 */ "matcharg ::= MATCH FULL",
 /*  45 */ "matcharg ::=",
 /*  46 */ "refact ::= SET NULL",
 /*  47 */ "refact ::= SET DEFAULT",
 /*  48 */ "refact ::= CASCADE",
 /*  49 */ "refact ::= RESTRICT",
 /*  50 */ "refact ::= NO ACTION",
 /*  51 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  52 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  53 */ "init_deferred_pred_opt ::=",
 /*  54 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  55 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  56 */ "tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP",
 /*  57 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  58 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  59 */ "defer_subclause_opt ::=",
 /*  60 */ "onconf ::=",
 /*  61 */ "onconf ::= ON CONFLICT resolvetype",
 /*  62 */ "orconf ::=",
 /*  63 */ "orconf ::= OR resolvetype",
 /*  64 */ "resolvetype ::= IGNORE",
 /*  65 */ "resolvetype ::= REPLACE",
 /*  66 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  67 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  68 */ "ifexists ::= IF EXISTS",
 /*  69 */ "ifexists ::=",
 /*  70 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  71 */ "cmd ::= select",
 /*  72 */ "select ::= with selectnowith",
 /*  73 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  74 */ "multiselect_op ::= UNION",
 /*  75 */ "multiselect_op ::= UNION ALL",
 /*  76 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  77 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  78 */ "values ::= VALUES LP nexprlist RP",
 /*  79 */ "values ::= values COMMA LP exprlist RP",
 /*  80 */ "distinct ::= DISTINCT",
 /*  81 */ "distinct ::= ALL",
 /*  82 */ "distinct ::=",
 /*  83 */ "sclp ::=",
 /*  84 */ "selcollist ::= sclp expr as",
 /*  85 */ "selcollist ::= sclp STAR",
 /*  86 */ "selcollist ::= sclp nm DOT STAR",
 /*  87 */ "as ::= AS nm",
 /*  88 */ "as ::=",
 /*  89 */ "from ::=",
 /*  90 */ "from ::= FROM seltablist",
 /*  91 */ "stl_prefix ::= seltablist joinop",
 /*  92 */ "stl_prefix ::=",
 /*  93 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  94 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  95 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  96 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  97 */ "fullname ::= nm",
 /*  98 */ "joinop ::= COMMA|JOIN",
 /*  99 */ "joinop ::= JOIN_KW JOIN",
 /* 100 */ "joinop ::= JOIN_KW join_nm JOIN",
 /* 101 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 102 */ "on_opt ::= ON expr",
 /* 103 */ "on_opt ::=",
 /* 104 */ "indexed_opt ::=",
 /* 105 */ "indexed_opt ::= INDEXED BY nm",
 /* 106 */ "indexed_opt ::= NOT INDEXED",
 /* 107 */ "using_opt ::= USING LP idlist RP",
 /* 108 */ "using_opt ::=",
 /* 109 */ "orderby_opt ::=",
 /* 110 */ "orderby_opt ::= ORDER BY sortlist",
 /* 111 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 112 */ "sortlist ::= expr sortorder",
 /* 113 */ "col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc",
 /* 114 */ "col_list_with_autoinc ::= expr autoinc",
 /* 115 */ "enable ::= ENABLE",
 /* 116 */ "enable ::= DISABLE",
 /* 117 */ "sortorder ::= ASC",
 /* 118 */ "sortorder ::= DESC",
 /* 119 */ "sortorder ::=",
 /* 120 */ "groupby_opt ::=",
 /* 121 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 122 */ "having_opt ::=",
 /* 123 */ "having_opt ::= HAVING expr",
 /* 124 */ "limit_opt ::=",
 /* 125 */ "limit_opt ::= LIMIT expr",
 /* 126 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 127 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 128 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 129 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 130 */ "where_opt ::=",
 /* 131 */ "where_opt ::= WHERE expr",
 /* 132 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 133 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 134 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 135 */ "setlist ::= nm EQ expr",
 /* 136 */ "setlist ::= LP idlist RP EQ expr",
 /* 137 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 138 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 139 */ "insert_cmd ::= INSERT orconf",
 /* 140 */ "insert_cmd ::= REPLACE",
 /* 141 */ "idlist_opt ::=",
 /* 142 */ "idlist_opt ::= LP idlist RP",
 /* 143 */ "idlist ::= idlist COMMA nm",
 /* 144 */ "idlist ::= nm",
 /* 145 */ "expr ::= LP expr RP",
 /* 146 */ "term ::= NULL",
 /* 147 */ "expr ::= ID|INDEXED",
 /* 148 */ "expr ::= JOIN_KW",
 /* 149 */ "expr ::= nm DOT nm",
 /* 150 */ "term ::= FLOAT|BLOB",
 /* 151 */ "term ::= STRING",
 /* 152 */ "term ::= FALSE",
 /* 153 */ "term ::= TRUE",
 /* 154 */ "term ::= UNKNOWN",
 /* 155 */ "term ::= INTEGER",
 /* 156 */ "expr ::= VARIABLE",
 /* 157 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 158 */ "expr ::= CAST LP expr AS typedef RP",
 /* 159 */ "expr ::= TRIM LP trim_operands RP",
 /* 160 */ "trim_operands ::= trim_from_clause expr",
 /* 161 */ "trim_operands ::= expr",
 /* 162 */ "trim_from_clause ::= expr FROM",
 /* 163 */ "trim_from_clause ::= trim_specification expr_optional FROM",
 /* 164 */ "expr_optional ::=",
 /* 165 */ "expr_optional ::= expr",
 /* 166 */ "trim_specification ::= LEADING",
 /* 167 */ "trim_specification ::= TRAILING",
 /* 168 */ "trim_specification ::= BOTH",
 /* 169 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 170 */ "expr ::= type_func LP distinct exprlist RP",
 /* 171 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 172 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 173 */ "expr ::= expr AND expr",
 /* 174 */ "expr ::= expr OR expr",
 /* 175 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 176 */ "expr ::= expr EQ|NE expr",
 /* 177 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 178 */ "expr ::= expr PLUS|MINUS expr",
 /* 179 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 180 */ "expr ::= expr CONCAT expr",
 /* 181 */ "likeop ::= LIKE_KW|MATCH",
 /* 182 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 183 */ "expr ::= expr likeop expr",
 /* 184 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 185 */ "expr ::= expr IS NULL",
 /* 186 */ "expr ::= expr IS NOT NULL",
 /* 187 */ "expr ::= NOT expr",
 /* 188 */ "expr ::= BITNOT expr",
 /* 189 */ "expr ::= MINUS expr",
 /* 190 */ "expr ::= PLUS expr",
 /* 191 */ "between_op ::= BETWEEN",
 /* 192 */ "between_op ::= NOT BETWEEN",
 /* 193 */ "expr ::= expr between_op expr AND expr",
 /* 194 */ "in_op ::= IN",
 /* 195 */ "in_op ::= NOT IN",
 /* 196 */ "expr ::= expr in_op LP exprlist RP",
 /* 197 */ "expr ::= LP select RP",
 /* 198 */ "expr ::= expr in_op LP select RP",
 /* 199 */ "expr ::= expr in_op nm paren_exprlist",
 /* 200 */ "expr ::= EXISTS LP select RP",
 /* 201 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 202 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 203 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 204 */ "case_else ::= ELSE expr",
 /* 205 */ "case_else ::=",
 /* 206 */ "exprlist ::=",
 /* 207 */ "nexprlist ::= nexprlist COMMA expr",
 /* 208 */ "nexprlist ::= expr",
 /* 209 */ "paren_exprlist ::=",
 /* 210 */ "paren_exprlist ::= LP exprlist RP",
 /* 211 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 212 */ "uniqueflag ::= UNIQUE",
 /* 213 */ "uniqueflag ::=",
 /* 214 */ "eidlist_opt ::=",
 /* 215 */ "eidlist_opt ::= LP eidlist RP",
 /* 216 */ "eidlist ::= eidlist COMMA nm",
 /* 217 */ "eidlist ::= nm",
 /* 218 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 219 */ "cmd ::= SET SESSION nm EQ term",
 /* 220 */ "cmd ::= PRAGMA nm",
 /* 221 */ "cmd ::= PRAGMA nm LP nm RP",
 /* 222 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 223 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 224 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 225 */ "trigger_time ::= BEFORE",
 /* 226 */ "trigger_time ::= AFTER",
 /* 227 */ "trigger_time ::= INSTEAD OF",
 /* 228 */ "trigger_time ::=",
 /* 229 */ "trigger_event ::= DELETE|INSERT",
 /* 230 */ "trigger_event ::= UPDATE",
 /* 231 */ "trigger_event ::= UPDATE OF idlist",
 /* 232 */ "foreach_clause ::=",
 /* 233 */ "when_clause ::=",
 /* 234 */ "when_clause ::= WHEN expr",
 /* 235 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 236 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 237 */ "trnm ::= nm DOT nm",
 /* 238 */ "tridxby ::= INDEXED BY nm",
 /* 239 */ "tridxby ::= NOT INDEXED",
 /* 240 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 241 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 242 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 243 */ "trigger_cmd ::= select",
 /* 244 */ "expr ::= RAISE LP IGNORE RP",
 /* 245 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 246 */ "raisetype ::= ROLLBACK",
 /* 247 */ "raisetype ::= ABORT",
 /* 248 */ "raisetype ::= FAIL",
 /* 249 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 250 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 251 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 252 */ "alter_add_column ::= alter_table_start ADD column_name",
 /* 253 */ "column_name ::= COLUMN nm",
 /* 254 */ "column_name ::= nm",
 /* 255 */ "alter_column_def ::= alter_add_column typedef",
 /* 256 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 257 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 258 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 259 */ "unique_spec ::= UNIQUE",
 /* 260 */ "unique_spec ::= PRIMARY KEY",
 /* 261 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 262 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 263 */ "cmd ::= alter_table_start enable CHECK CONSTRAINT nm",
 /* 264 */ "with ::=",
 /* 265 */ "with ::= WITH wqlist",
 /* 266 */ "with ::= WITH RECURSIVE wqlist",
 /* 267 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 268 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 269 */ "typedef ::= TEXT",
 /* 270 */ "typedef ::= STRING_KW",
 /* 271 */ "typedef ::= SCALAR",
 /* 272 */ "typedef ::= BOOL",
 /* 273 */ "typedef ::= BOOLEAN",
 /* 274 */ "typedef ::= VARBINARY",
 /* 275 */ "char_len ::= LP INTEGER RP",
 /* 276 */ "typedef ::= VARCHAR char_len",
 /* 277 */ "number_typedef ::= NUMBER",
 /* 278 */ "number_typedef ::= DOUBLE",
 /* 279 */ "number_typedef ::= INT|INTEGER_KW",
 /* 280 */ "number_typedef ::= UNSIGNED",
 /* 281 */ "input ::= ecmd",
 /* 282 */ "explain ::=",
 /* 283 */ "cmdx ::= cmd",
 /* 284 */ "savepoint_opt ::= SAVEPOINT",
 /* 285 */ "savepoint_opt ::=",
 /* 286 */ "cmd ::= create_table create_table_args with_opts create_table_end",
 /* 287 */ "create_table_args ::= LP columnlist RP",
 /* 288 */ "with_opts ::= WITH engine_opts",
 /* 289 */ "with_opts ::=",
 /* 290 */ "columnlist ::= columnlist COMMA tcons",
 /* 291 */ "columnlist ::= columnlist COMMA column_def create_column_end",
 /* 292 */ "columnlist ::= column_def create_column_end",
 /* 293 */ "column_def ::= column_name_and_type carglist",
 /* 294 */ "columnlist ::= tcons",
 /* 295 */ "carglist ::= carglist ccons",
 /* 296 */ "carglist ::=",
 /* 297 */ "ccons ::= check_constraint_def",
 /* 298 */ "tcons ::= check_constraint_def",
 /* 299 */ "defer_subclause_opt ::= defer_subclause",
 /* 300 */ "resolvetype ::= raisetype",
 /* 301 */ "selectnowith ::= oneselect",
 /* 302 */ "oneselect ::= values",
 /* 303 */ "sclp ::= selcollist COMMA",
 /* 304 */ "as ::= ID|STRING",
 /* 305 */ "join_nm ::= ID|INDEXED",
 /* 306 */ "join_nm ::= JOIN_KW",
 /* 307 */ "expr ::= term",
 /* 308 */ "type_func ::= CHAR",
 /* 309 */ "exprlist ::= nexprlist",
 /* 310 */ "foreach_clause ::= FOR EACH ROW",
 /* 311 */ "trnm ::= nm",
 /* 312 */ "tridxby ::=",
 /* 313 */ "cmd ::= alter_column_def carglist create_column_end",
 /* 314 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 186: /* term */
    case 187: /* expr */
{
#line 962 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy114).pExpr, false);
#line 1590 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 191: /* eidlist_opt */
    case 199: /* col_list_with_autoinc */
    case 200: /* sortlist */
    case 201: /* eidlist */
    case 215: /* selcollist */
    case 218: /* groupby_opt */
    case 220: /* orderby_opt */
    case 223: /* nexprlist */
    case 224: /* exprlist */
    case 225: /* sclp */
    case 236: /* setlist */
    case 247: /* paren_exprlist */
    case 248: /* case_exprlist */
{
#line 1516 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy266));
#line 1609 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 208: /* fullname */
    case 216: /* from */
    case 227: /* seltablist */
    case 228: /* stl_prefix */
{
#line 711 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy93));
#line 1619 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 209: /* select */
    case 210: /* selectnowith */
    case 211: /* oneselect */
    case 222: /* values */
{
#line 473 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy149));
#line 1629 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 212: /* with */
    case 266: /* wqlist */
{
#line 1814 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy473));
#line 1637 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 217: /* where_opt */
    case 219: /* having_opt */
    case 231: /* on_opt */
    case 249: /* case_else */
    case 256: /* when_clause */
{
#line 871 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy20), false);
#line 1648 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 232: /* using_opt */
    case 234: /* idlist */
    case 238: /* idlist_opt */
{
#line 754 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy520));
#line 1657 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 239: /* trim_operands */
    case 240: /* trim_from_clause */
{
#line 1133 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy343));
#line 1665 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 242: /* expr_optional */
{
#line 1164 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy513), false);
#line 1672 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 252: /* trigger_cmd_list */
    case 257: /* trigger_cmd */
{
#line 1615 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy359));
#line 1680 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
    case 254: /* trigger_event */
{
#line 1596 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy68).b);
#line 1687 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 44 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1863 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 163, 3 },
  { 163, 1 },
  { 164, 1 },
  { 164, 3 },
  { 166, 2 },
  { 166, 1 },
  { 166, 1 },
  { 166, 2 },
  { 166, 3 },
  { 166, 4 },
  { 169, 4 },
  { 173, 1 },
  { 174, 0 },
  { 174, 3 },
  { 176, 3 },
  { 172, 0 },
  { 180, 2 },
  { 179, 1 },
  { 168, 1 },
  { 185, 2 },
  { 185, 0 },
  { 184, 2 },
  { 184, 4 },
  { 184, 3 },
  { 184, 3 },
  { 184, 2 },
  { 184, 3 },
  { 184, 4 },
  { 184, 2 },
  { 190, 5 },
  { 184, 6 },
  { 184, 1 },
  { 184, 2 },
  { 183, 0 },
  { 183, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 2 },
  { 193, 2 },
  { 193, 0 },
  { 195, 3 },
  { 196, 3 },
  { 192, 2 },
  { 192, 2 },
  { 192, 2 },
  { 192, 0 },
  { 197, 2 },
  { 197, 2 },
  { 197, 1 },
  { 197, 1 },
  { 197, 2 },
  { 194, 3 },
  { 194, 2 },
  { 198, 0 },
  { 198, 2 },
  { 198, 2 },
  { 177, 6 },
  { 177, 5 },
  { 177, 12 },
  { 202, 0 },
  { 188, 0 },
  { 188, 3 },
  { 204, 0 },
  { 204, 2 },
  { 205, 1 },
  { 205, 1 },
  { 166, 4 },
  { 166, 4 },
  { 207, 2 },
  { 207, 0 },
  { 166, 7 },
  { 166, 1 },
  { 209, 2 },
  { 210, 3 },
  { 213, 1 },
  { 213, 2 },
  { 213, 1 },
  { 211, 9 },
  { 222, 4 },
  { 222, 5 },
  { 214, 1 },
  { 214, 1 },
  { 214, 0 },
  { 225, 0 },
  { 215, 3 },
  { 215, 2 },
  { 215, 4 },
  { 226, 2 },
  { 226, 0 },
  { 216, 0 },
  { 216, 2 },
  { 228, 2 },
  { 228, 0 },
  { 227, 6 },
  { 227, 8 },
  { 227, 7 },
  { 227, 7 },
  { 208, 1 },
  { 229, 1 },
  { 229, 2 },
  { 229, 3 },
  { 229, 4 },
  { 231, 2 },
  { 231, 0 },
  { 230, 0 },
  { 230, 3 },
  { 230, 2 },
  { 232, 4 },
  { 232, 0 },
  { 220, 0 },
  { 220, 3 },
  { 200, 4 },
  { 200, 2 },
  { 199, 4 },
  { 199, 2 },
  { 235, 1 },
  { 235, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 0 },
  { 218, 0 },
  { 218, 3 },
  { 219, 0 },
  { 219, 2 },
  { 221, 0 },
  { 221, 2 },
  { 221, 4 },
  { 221, 4 },
  { 166, 6 },
  { 166, 3 },
  { 217, 0 },
  { 217, 2 },
  { 166, 8 },
  { 236, 5 },
  { 236, 7 },
  { 236, 3 },
  { 236, 5 },
  { 166, 6 },
  { 166, 7 },
  { 237, 2 },
  { 237, 1 },
  { 238, 0 },
  { 238, 3 },
  { 234, 3 },
  { 234, 1 },
  { 187, 3 },
  { 186, 1 },
  { 187, 1 },
  { 187, 1 },
  { 187, 3 },
  { 186, 1 },
  { 186, 1 },
  { 186, 1 },
  { 186, 1 },
  { 186, 1 },
  { 186, 1 },
  { 187, 1 },
  { 187, 3 },
  { 187, 6 },
  { 187, 4 },
  { 239, 2 },
  { 239, 1 },
  { 240, 2 },
  { 240, 3 },
  { 242, 0 },
  { 242, 1 },
  { 241, 1 },
  { 241, 1 },
  { 241, 1 },
  { 187, 5 },
  { 187, 5 },
  { 187, 4 },
  { 187, 5 },
  { 187, 3 },
  { 187, 3 },
  { 187, 3 },
  { 187, 3 },
  { 187, 3 },
  { 187, 3 },
  { 187, 3 },
  { 187, 3 },
  { 244, 1 },
  { 244, 2 },
  { 187, 3 },
  { 187, 5 },
  { 187, 3 },
  { 187, 4 },
  { 187, 2 },
  { 187, 2 },
  { 187, 2 },
  { 187, 2 },
  { 245, 1 },
  { 245, 2 },
  { 187, 5 },
  { 246, 1 },
  { 246, 2 },
  { 187, 5 },
  { 187, 3 },
  { 187, 5 },
  { 187, 4 },
  { 187, 4 },
  { 187, 5 },
  { 248, 5 },
  { 248, 4 },
  { 249, 2 },
  { 249, 0 },
  { 224, 0 },
  { 223, 3 },
  { 223, 1 },
  { 247, 0 },
  { 247, 3 },
  { 166, 10 },
  { 250, 1 },
  { 250, 0 },
  { 191, 0 },
  { 191, 3 },
  { 201, 3 },
  { 201, 1 },
  { 166, 6 },
  { 166, 5 },
  { 166, 2 },
  { 166, 5 },
  { 166, 7 },
  { 166, 5 },
  { 251, 9 },
  { 253, 1 },
  { 253, 1 },
  { 253, 2 },
  { 253, 0 },
  { 254, 1 },
  { 254, 1 },
  { 254, 3 },
  { 255, 0 },
  { 256, 0 },
  { 256, 2 },
  { 252, 3 },
  { 252, 2 },
  { 258, 3 },
  { 259, 3 },
  { 259, 2 },
  { 257, 7 },
  { 257, 5 },
  { 257, 5 },
  { 257, 1 },
  { 187, 4 },
  { 187, 6 },
  { 206, 1 },
  { 206, 1 },
  { 206, 1 },
  { 166, 4 },
  { 260, 3 },
  { 261, 4 },
  { 262, 3 },
  { 263, 2 },
  { 263, 1 },
  { 264, 2 },
  { 166, 12 },
  { 166, 5 },
  { 166, 5 },
  { 265, 1 },
  { 265, 2 },
  { 166, 4 },
  { 166, 6 },
  { 166, 5 },
  { 212, 0 },
  { 212, 2 },
  { 212, 3 },
  { 266, 6 },
  { 266, 8 },
  { 182, 1 },
  { 182, 1 },
  { 182, 1 },
  { 182, 1 },
  { 182, 1 },
  { 182, 1 },
  { 267, 3 },
  { 182, 2 },
  { 268, 1 },
  { 268, 1 },
  { 268, 1 },
  { 268, 1 },
  { 162, 1 },
  { 164, 0 },
  { 165, 1 },
  { 167, 1 },
  { 167, 0 },
  { 166, 4 },
  { 170, 3 },
  { 171, 2 },
  { 171, 0 },
  { 175, 3 },
  { 175, 4 },
  { 175, 2 },
  { 178, 2 },
  { 175, 1 },
  { 181, 2 },
  { 181, 0 },
  { 184, 1 },
  { 177, 1 },
  { 202, 1 },
  { 205, 1 },
  { 210, 1 },
  { 211, 1 },
  { 225, 2 },
  { 226, 1 },
  { 233, 1 },
  { 233, 1 },
  { 187, 1 },
  { 243, 1 },
  { 224, 1 },
  { 255, 3 },
  { 258, 1 },
  { 259, 0 },
  { 166, 3 },
  { 182, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 123 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2321 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 127 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2329 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 132 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2334 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 133 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2339 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 163 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2344 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 164 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2349 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 165 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2354 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 169 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2361 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 172 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2368 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 175 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2375 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 182 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy150);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2386 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 189 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2391 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 33: /* autoinc ::= */ yytestcase(yyruleno==33);
      case 53: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==53);
      case 59: /* defer_subclause_opt ::= */ yytestcase(yyruleno==59);
      case 69: /* ifexists ::= */ yytestcase(yyruleno==69);
      case 82: /* distinct ::= */ yytestcase(yyruleno==82);
#line 192 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy150 = 0;}
#line 2401 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 193 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy150 = 1;}
#line 2406 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 14: /* engine_opts ::= ENGINE EQ STRING */
#line 200 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  /* Note that specifying engine clause overwrites default engine. */
  if (yymsp[0].minor.yy0.n > ENGINE_NAME_MAX) {
    diag_set(ClientError, ER_CREATE_SPACE,
             pParse->create_table_def.new_space->def->name,
             "space engine name is too long");
    pParse->is_aborted = true;
    return;
  }
  /* Need to dequote name. */
  char *normalized_name = sql_name_from_token(pParse->db, &yymsp[0].minor.yy0);
  if (normalized_name == NULL)
    return;
  memcpy(pParse->create_table_def.new_space->def->engine_name, normalized_name,
         strlen(normalized_name) + 1);
  sqlDbFree(pParse->db, normalized_name);
}
#line 2427 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 15: /* create_table_end ::= */
#line 218 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ sqlEndTable(pParse); }
#line 2432 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 16: /* column_name_and_type ::= nm typedef */
#line 236 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, NULL, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy122);
  sql_create_column_start(pParse);
}
#line 2440 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 17: /* create_column_end ::= autoinc */
#line 241 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  uint32_t fieldno = pParse->create_column_def.space->def->field_count - 1;
  if (yymsp[0].minor.yy150 == 1 && sql_add_autoincrement(pParse, fieldno) != 0)
    return;
  if (pParse->create_table_def.new_space == NULL)
    sql_create_column_end(pParse);
}
#line 2451 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 18: /* nm ::= ID|INDEXED */
#line 283 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2462 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 19: /* cconsname ::= CONSTRAINT nm */
#line 299 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy429 = yymsp[0].minor.yy0; }
#line 2467 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 20: /* cconsname ::= */
#line 300 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[1].minor.yy429 = Token_nil; }
#line 2472 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 21: /* ccons ::= DEFAULT term */
      case 23: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==23);
#line 301 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy114);}
#line 2478 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 22: /* ccons ::= DEFAULT LP expr RP */
#line 302 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy114);}
#line 2483 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 24: /* ccons ::= DEFAULT MINUS term */
#line 304 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy114.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy114.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2494 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 25: /* ccons ::= NULL onconf */
#line 315 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy150 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy150);
}
#line 2504 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 26: /* ccons ::= NOT NULL onconf */
#line 321 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy150);}
#line 2509 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 27: /* ccons ::= cconsname PRIMARY KEY sortorder */
#line 322 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-3].minor.yy429, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[0].minor.yy150, false);
  sqlAddPrimaryKey(pParse);
}
#line 2518 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 28: /* ccons ::= cconsname UNIQUE */
#line 327 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy429, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2528 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 29: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 336 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy429, &yymsp[-1].minor.yy114);
  sql_create_check_contraint(pParse);
}
#line 2536 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 30: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 341 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy429, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy266, yymsp[-1].minor.yy150, yymsp[0].minor.yy150,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2545 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 31: /* ccons ::= defer_subclause */
#line 346 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy150);}
#line 2550 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 32: /* ccons ::= COLLATE ID|INDEXED */
#line 347 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2555 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 34: /* autoinc ::= AUTOINCR */
#line 352 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = 1;}
#line 2560 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 35: /* refargs ::= refact_update */
#line 360 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yylhsminor.yy150 = (yymsp[0].minor.yy150 << 8); }
#line 2565 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy150 = yylhsminor.yy150;
        break;
      case 36: /* refargs ::= refact_delete */
#line 361 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yylhsminor.yy150 = yymsp[0].minor.yy150; }
#line 2571 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy150 = yylhsminor.yy150;
        break;
      case 37: /* refargs ::= refact_delete refact_update */
#line 362 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yylhsminor.yy150 = (yymsp[0].minor.yy150 << 8) | (yymsp[-1].minor.yy150) ; }
#line 2577 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-1].minor.yy150 = yylhsminor.yy150;
        break;
      case 38: /* refargs ::= refact_update refact_delete */
#line 363 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yylhsminor.yy150 = (yymsp[-1].minor.yy150 << 8) | (yymsp[0].minor.yy150) ; }
#line 2583 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-1].minor.yy150 = yylhsminor.yy150;
        break;
      case 39: /* refargs ::= */
#line 364 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[1].minor.yy150 = 0; }
#line 2589 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 40: /* refact_update ::= ON UPDATE refact */
      case 41: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==41);
#line 367 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-2].minor.yy150 = yymsp[0].minor.yy150; }
#line 2595 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 42: /* matcharg ::= MATCH SIMPLE */
#line 372 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy150 = FKEY_MATCH_SIMPLE; }
#line 2600 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 43: /* matcharg ::= MATCH PARTIAL */
#line 373 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy150 = FKEY_MATCH_PARTIAL; }
#line 2605 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 44: /* matcharg ::= MATCH FULL */
#line 374 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy150 = FKEY_MATCH_FULL; }
#line 2610 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 45: /* matcharg ::= */
#line 375 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[1].minor.yy150 = FKEY_MATCH_SIMPLE; }
#line 2615 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 46: /* refact ::= SET NULL */
#line 378 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy150 = FKEY_ACTION_SET_NULL; }
#line 2620 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 47: /* refact ::= SET DEFAULT */
#line 379 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy150 = FKEY_ACTION_SET_DEFAULT; }
#line 2625 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 48: /* refact ::= CASCADE */
#line 380 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy150 = FKEY_ACTION_CASCADE; }
#line 2630 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 49: /* refact ::= RESTRICT */
#line 381 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy150 = FKEY_ACTION_RESTRICT; }
#line 2635 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 50: /* refact ::= NO ACTION */
#line 382 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy150 = FKEY_NO_ACTION; }
#line 2640 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 51: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 384 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy150 = 0;}
#line 2645 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 52: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 63: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==63);
      case 139: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==139);
#line 385 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy150 = yymsp[0].minor.yy150;}
#line 2652 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 54: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 68: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==68);
      case 192: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==192);
      case 195: /* in_op ::= NOT IN */ yytestcase(yyruleno==195);
#line 388 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy150 = 1;}
#line 2660 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 55: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 389 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy150 = 0;}
#line 2665 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 56: /* tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP */
#line 391 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-5].minor.yy429, yymsp[-1].minor.yy266,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2674 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 57: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 396 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy429, yymsp[-1].minor.yy266,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2684 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 58: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 404 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy429, yymsp[-7].minor.yy266, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy266, yymsp[-2].minor.yy150, yymsp[-1].minor.yy150, yymsp[0].minor.yy150);
  sql_create_foreign_key(pParse);
}
#line 2692 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 60: /* onconf ::= */
#line 419 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy150 = ON_CONFLICT_ACTION_ABORT;}
#line 2697 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 61: /* onconf ::= ON CONFLICT resolvetype */
#line 420 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy150 = yymsp[0].minor.yy150;}
#line 2702 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 62: /* orconf ::= */
#line 421 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy150 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2707 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 64: /* resolvetype ::= IGNORE */
#line 424 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = ON_CONFLICT_ACTION_IGNORE;}
#line 2712 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 65: /* resolvetype ::= REPLACE */
      case 140: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==140);
#line 425 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = ON_CONFLICT_ACTION_REPLACE;}
#line 2718 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 66: /* cmd ::= DROP TABLE ifexists fullname */
#line 430 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy93, &t, yymsp[-1].minor.yy150);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2728 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 67: /* cmd ::= DROP VIEW ifexists fullname */
#line 437 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy93, &t, yymsp[-1].minor.yy150);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2738 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 70: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 451 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy266, yymsp[0].minor.yy149, yymsp[-4].minor.yy150);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy149);
  }
}
#line 2751 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 71: /* cmd ::= select */
#line 463 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy149, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy149);
  sql_select_delete(pParse->db, yymsp[0].minor.yy149);
}
#line 2763 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 72: /* select ::= with selectnowith */
#line 506 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy149;
  if( p ){
    p->pWith = yymsp[-1].minor.yy473;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy473);
  }
  yymsp[-1].minor.yy149 = p; /*A-overwrites-W*/
}
#line 2777 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 73: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 519 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy149;
  Select *pLhs = yymsp[-2].minor.yy149;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy150;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy150!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy149 = pRhs;
}
#line 2803 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 74: /* multiselect_op ::= UNION */
      case 76: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==76);
#line 542 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2809 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 75: /* multiselect_op ::= UNION ALL */
#line 543 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy150 = TK_ALL;}
#line 2814 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 77: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 547 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy440.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy266);
  yymsp[-8].minor.yy149 = sqlSelectNew(pParse,yymsp[-6].minor.yy266,yymsp[-5].minor.yy93,yymsp[-4].minor.yy20,yymsp[-3].minor.yy266,yymsp[-2].minor.yy20,yymsp[-1].minor.yy266,yymsp[-7].minor.yy150,yymsp[0].minor.yy440.pLimit,yymsp[0].minor.yy440.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy149!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy149->zSelName), yymsp[-8].minor.yy149->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy149->zSelName), yymsp[-8].minor.yy149->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2850 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 78: /* values ::= VALUES LP nexprlist RP */
#line 583 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy149 = sqlSelectNew(pParse,yymsp[-1].minor.yy266,0,0,0,0,0,SF_Values,0,0);
}
#line 2857 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 79: /* values ::= values COMMA LP exprlist RP */
#line 586 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy149;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy266,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy149 = pRight;
  }else{
    yymsp[-4].minor.yy149 = pLeft;
  }
}
#line 2873 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 80: /* distinct ::= DISTINCT */
#line 603 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = SF_Distinct;}
#line 2878 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 81: /* distinct ::= ALL */
#line 604 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = SF_All;}
#line 2883 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 83: /* sclp ::= */
      case 109: /* orderby_opt ::= */ yytestcase(yyruleno==109);
      case 120: /* groupby_opt ::= */ yytestcase(yyruleno==120);
      case 206: /* exprlist ::= */ yytestcase(yyruleno==206);
      case 209: /* paren_exprlist ::= */ yytestcase(yyruleno==209);
      case 214: /* eidlist_opt ::= */ yytestcase(yyruleno==214);
#line 617 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy266 = 0;}
#line 2893 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 84: /* selcollist ::= sclp expr as */
#line 618 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy266 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy266, yymsp[-1].minor.yy114.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy266, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy266,&yymsp[-1].minor.yy114);
}
#line 2902 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 85: /* selcollist ::= sclp STAR */
#line 623 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy266 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy266, p);
}
#line 2914 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 86: /* selcollist ::= sclp nm DOT STAR */
#line 631 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy266 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy266, pDot);
}
#line 2928 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 87: /* as ::= AS nm */
#line 646 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2933 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 88: /* as ::= */
#line 648 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2938 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 89: /* from ::= */
#line 660 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy93 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy93));}
#line 2943 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 90: /* from ::= FROM seltablist */
#line 661 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy93 = yymsp[0].minor.yy93;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy93);
}
#line 2951 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 91: /* stl_prefix ::= seltablist joinop */
#line 669 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy93 && yymsp[-1].minor.yy93->nSrc>0) ) yymsp[-1].minor.yy93->a[yymsp[-1].minor.yy93->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy150;
}
#line 2958 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 92: /* stl_prefix ::= */
#line 672 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy93 = 0;}
#line 2963 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 93: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 674 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy93 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy93,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy20,yymsp[0].minor.yy520);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy93, &yymsp[-2].minor.yy0);
}
#line 2971 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 679 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy93 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy93,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy20,yymsp[0].minor.yy520);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy93, yymsp[-4].minor.yy266);
}
#line 2979 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 95: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 684 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy93 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy93,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy149,yymsp[-1].minor.yy20,yymsp[0].minor.yy520);
}
#line 2986 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 96: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 688 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy93==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy20==0 && yymsp[0].minor.yy520==0 ){
    yymsp[-6].minor.yy93 = yymsp[-4].minor.yy93;
  }else if( yymsp[-4].minor.yy93->nSrc==1 ){
    yymsp[-6].minor.yy93 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy93,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy20,yymsp[0].minor.yy520);
    if( yymsp[-6].minor.yy93 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy93->a[yymsp[-6].minor.yy93->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy93->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy93);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy93);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy93,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy93 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy93,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy20,yymsp[0].minor.yy520);
  }
}
#line 3011 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 97: /* fullname ::= nm */
#line 712 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  /* yylhsminor.yy93-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy93 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy93 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3023 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy93 = yylhsminor.yy93;
        break;
      case 98: /* joinop ::= COMMA|JOIN */
#line 725 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy150 = JT_INNER; }
#line 3029 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 99: /* joinop ::= JOIN_KW JOIN */
#line 727 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy150 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 3034 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 100: /* joinop ::= JOIN_KW join_nm JOIN */
#line 729 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy150 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 3039 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 101: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 731 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-3].minor.yy150 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 3044 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 102: /* on_opt ::= ON expr */
      case 123: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==123);
      case 131: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==131);
      case 204: /* case_else ::= ELSE expr */ yytestcase(yyruleno==204);
#line 735 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy20 = yymsp[0].minor.yy114.pExpr;}
#line 3052 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 103: /* on_opt ::= */
      case 122: /* having_opt ::= */ yytestcase(yyruleno==122);
      case 130: /* where_opt ::= */ yytestcase(yyruleno==130);
      case 205: /* case_else ::= */ yytestcase(yyruleno==205);
#line 736 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy20 = 0;}
#line 3060 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 104: /* indexed_opt ::= */
#line 749 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3065 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 105: /* indexed_opt ::= INDEXED BY nm */
#line 750 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3070 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 106: /* indexed_opt ::= NOT INDEXED */
#line 751 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3075 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 107: /* using_opt ::= USING LP idlist RP */
#line 755 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-3].minor.yy520 = yymsp[-1].minor.yy520;}
#line 3080 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 108: /* using_opt ::= */
      case 141: /* idlist_opt ::= */ yytestcase(yyruleno==141);
#line 756 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy520 = 0;}
#line 3086 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 110: /* orderby_opt ::= ORDER BY sortlist */
      case 121: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==121);
#line 770 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy266 = yymsp[0].minor.yy266;}
#line 3092 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 111: /* sortlist ::= sortlist COMMA expr sortorder */
#line 771 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy266 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy266,yymsp[-1].minor.yy114.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy266,yymsp[0].minor.yy150);
}
#line 3100 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 112: /* sortlist ::= expr sortorder */
#line 775 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  /* yylhsminor.yy266-overwrites-yymsp[-1].minor.yy114. */
  yylhsminor.yy266 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy114.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy266,yymsp[0].minor.yy150);
}
#line 3109 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-1].minor.yy266 = yylhsminor.yy266;
        break;
      case 113: /* col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc */
#line 789 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  uint32_t fieldno;
  if (yymsp[0].minor.yy150 == 1) {
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy114.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  yymsp[-3].minor.yy266 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy266, yymsp[-1].minor.yy114.pExpr);
}
#line 3124 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 114: /* col_list_with_autoinc ::= expr autoinc */
#line 800 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  if (yymsp[0].minor.yy150 == 1) {
    uint32_t fieldno = 0;
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy114.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  /* yylhsminor.yy266-overwrites-yymsp[-1].minor.yy114. */
  yylhsminor.yy266 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy114.pExpr);
}
#line 3139 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-1].minor.yy266 = yylhsminor.yy266;
        break;
      case 115: /* enable ::= ENABLE */
#line 813 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy295 = true;}
#line 3145 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 116: /* enable ::= DISABLE */
#line 814 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy295 = false;}
#line 3150 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 117: /* sortorder ::= ASC */
#line 818 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = SORT_ORDER_ASC;}
#line 3155 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 118: /* sortorder ::= DESC */
#line 819 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = SORT_ORDER_DESC;}
#line 3160 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 119: /* sortorder ::= */
#line 820 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy150 = SORT_ORDER_UNDEF;}
#line 3165 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 124: /* limit_opt ::= */
#line 845 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy440.pLimit = 0; yymsp[1].minor.yy440.pOffset = 0;}
#line 3170 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 125: /* limit_opt ::= LIMIT expr */
#line 846 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy440.pLimit = yymsp[0].minor.yy114.pExpr; yymsp[-1].minor.yy440.pOffset = 0;}
#line 3175 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 126: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 848 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-3].minor.yy440.pLimit = yymsp[-2].minor.yy114.pExpr; yymsp[-3].minor.yy440.pOffset = yymsp[0].minor.yy114.pExpr;}
#line 3180 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 127: /* limit_opt ::= LIMIT expr COMMA expr */
#line 850 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-3].minor.yy440.pOffset = yymsp[-2].minor.yy114.pExpr; yymsp[-3].minor.yy440.pLimit = yymsp[0].minor.yy114.pExpr;}
#line 3185 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 128: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 854 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy473, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy93, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy93,yymsp[0].minor.yy20);
}
#line 3197 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 129: /* cmd ::= TRUNCATE TABLE fullname */
#line 865 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy93);
}
#line 3205 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 132: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 879 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy473, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy93, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy266 != NULL && yymsp[-1].minor.yy266->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy266->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy93,yymsp[-1].minor.yy266,yymsp[0].minor.yy20,yymsp[-5].minor.yy150);
}
#line 3222 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 133: /* setlist ::= setlist COMMA nm EQ expr */
#line 896 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy266 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy266, yymsp[0].minor.yy114.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy266, &yymsp[-2].minor.yy0, 1);
}
#line 3230 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 134: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 900 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy266 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy266, yymsp[-3].minor.yy520, yymsp[0].minor.yy114.pExpr);
}
#line 3237 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 135: /* setlist ::= nm EQ expr */
#line 903 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yylhsminor.yy266 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy114.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy266, &yymsp[-2].minor.yy0, 1);
}
#line 3245 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-2].minor.yy266 = yylhsminor.yy266;
        break;
      case 136: /* setlist ::= LP idlist RP EQ expr */
#line 907 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy266 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy520, yymsp[0].minor.yy114.pExpr);
}
#line 3253 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 137: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 913 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy473, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy93, yymsp[0].minor.yy149, yymsp[-1].minor.yy520, yymsp[-4].minor.yy150);
}
#line 3264 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 138: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 921 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy473, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy93, 0, yymsp[-2].minor.yy520, yymsp[-5].minor.yy150);
}
#line 3275 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 142: /* idlist_opt ::= LP idlist RP */
#line 939 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy520 = yymsp[-1].minor.yy520;}
#line 3280 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 143: /* idlist ::= idlist COMMA nm */
#line 940 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy520 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy520,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy520 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3291 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 144: /* idlist ::= nm */
#line 947 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  /* yylhsminor.yy520-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy520 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy520 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3303 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy520 = yylhsminor.yy520;
        break;
      case 145: /* expr ::= LP expr RP */
#line 1050 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy114,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy114.pExpr = yymsp[-1].minor.yy114.pExpr;}
#line 3309 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 146: /* term ::= NULL */
      case 150: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==150);
      case 151: /* term ::= STRING */ yytestcase(yyruleno==151);
      case 152: /* term ::= FALSE */ yytestcase(yyruleno==152);
      case 153: /* term ::= TRUE */ yytestcase(yyruleno==153);
      case 154: /* term ::= UNKNOWN */ yytestcase(yyruleno==154);
#line 1051 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy114,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3319 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 147: /* expr ::= ID|INDEXED */
      case 148: /* expr ::= JOIN_KW */ yytestcase(yyruleno==148);
#line 1052 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy114,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3325 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 149: /* expr ::= nm DOT nm */
#line 1054 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy114,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy114.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3344 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 155: /* term ::= INTEGER */
#line 1075 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yylhsminor.yy114.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy114.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy114.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy114.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy114.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy114.pExpr ) yylhsminor.yy114.pExpr->flags |= EP_Leaf;
}
#line 3359 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy114 = yylhsminor.yy114;
        break;
      case 156: /* expr ::= VARIABLE */
#line 1086 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy114, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
             pParse->line_pos, "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy114.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy114, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy114.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy114.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy114, &t, &t);
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy114.pExpr = NULL;
  }
}
#line 3389 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy114 = yylhsminor.yy114;
        break;
      case 157: /* expr ::= expr COLLATE ID|INDEXED */
#line 1111 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy114.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy114.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy114.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3398 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 158: /* expr ::= CAST LP expr AS typedef RP */
#line 1116 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy114,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy114.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy114.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy114.pExpr->type = yymsp[-1].minor.yy122.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy114.pExpr, yymsp[-3].minor.yy114.pExpr, 0);
}
#line 3412 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 159: /* expr ::= TRIM LP trim_operands RP */
#line 1127 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yylhsminor.yy114.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy343, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy114, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3420 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-3].minor.yy114 = yylhsminor.yy114;
        break;
      case 160: /* trim_operands ::= trim_from_clause expr */
#line 1135 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yylhsminor.yy343 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy343, yymsp[0].minor.yy114.pExpr);
}
#line 3428 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-1].minor.yy343 = yylhsminor.yy343;
        break;
      case 161: /* trim_operands ::= expr */
#line 1139 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yylhsminor.yy343 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy114.pExpr);
}
#line 3436 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy343 = yylhsminor.yy343;
        break;
      case 162: /* trim_from_clause ::= expr FROM */
#line 1151 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yylhsminor.yy343 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy114.pExpr);
}
#line 3444 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-1].minor.yy343 = yylhsminor.yy343;
        break;
      case 163: /* trim_from_clause ::= trim_specification expr_optional FROM */
#line 1155 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy203]);
  yylhsminor.yy343 = sql_expr_list_append(pParse->db, NULL, p);
  if (yymsp[-1].minor.yy513 != NULL)
    yylhsminor.yy343 = sql_expr_list_append(pParse->db, yylhsminor.yy343, yymsp[-1].minor.yy513);
}
#line 3456 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-2].minor.yy343 = yylhsminor.yy343;
        break;
      case 164: /* expr_optional ::= */
#line 1166 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[1].minor.yy513 = NULL; }
#line 3462 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 165: /* expr_optional ::= expr */
#line 1167 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yylhsminor.yy513 = yymsp[0].minor.yy114.pExpr; }
#line 3467 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy513 = yylhsminor.yy513;
        break;
      case 166: /* trim_specification ::= LEADING */
#line 1171 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy203 = TRIM_LEADING; }
#line 3473 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 167: /* trim_specification ::= TRAILING */
#line 1172 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy203 = TRIM_TRAILING; }
#line 3478 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 168: /* trim_specification ::= BOTH */
#line 1173 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy203 = TRIM_BOTH; }
#line 3483 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 169: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 170: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==170);
#line 1175 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy266 && yymsp[-1].minor.yy266->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy266->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy114.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy266, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy114,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy150==SF_Distinct && yylhsminor.yy114.pExpr ){
    yylhsminor.yy114.pExpr->flags |= EP_Distinct;
  }
}
#line 3502 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-4].minor.yy114 = yylhsminor.yy114;
        break;
      case 171: /* expr ::= ID|INDEXED LP STAR RP */
#line 1210 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yylhsminor.yy114.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy114,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3511 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-3].minor.yy114 = yylhsminor.yy114;
        break;
      case 172: /* expr ::= LP nexprlist COMMA expr RP */
#line 1245 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy266, yymsp[-1].minor.yy114.pExpr);
  yylhsminor.yy114.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy114.pExpr ){
    yylhsminor.yy114.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy114, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3526 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-4].minor.yy114 = yylhsminor.yy114;
        break;
      case 173: /* expr ::= expr AND expr */
      case 174: /* expr ::= expr OR expr */ yytestcase(yyruleno==174);
      case 175: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==175);
      case 176: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==176);
      case 177: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==177);
      case 178: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==178);
      case 179: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==179);
      case 180: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==180);
#line 1256 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy114,&yymsp[0].minor.yy114);}
#line 3539 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 181: /* likeop ::= LIKE_KW|MATCH */
#line 1269 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3544 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 182: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1270 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3549 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 183: /* expr ::= expr likeop expr */
#line 1271 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy114.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy114.pExpr);
  yymsp[-2].minor.yy114.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy114);
  yymsp[-2].minor.yy114.zEnd = yymsp[0].minor.yy114.zEnd;
  if( yymsp[-2].minor.yy114.pExpr ) yymsp[-2].minor.yy114.pExpr->flags |= EP_InfixFunc;
}
#line 3564 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 184: /* expr ::= expr likeop expr ESCAPE expr */
#line 1282 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy114.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy114.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy114.pExpr);
  yymsp[-4].minor.yy114.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy114);
  yymsp[-4].minor.yy114.zEnd = yymsp[0].minor.yy114.zEnd;
  if( yymsp[-4].minor.yy114.pExpr ) yymsp[-4].minor.yy114.pExpr->flags |= EP_InfixFunc;
}
#line 3580 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 185: /* expr ::= expr IS NULL */
#line 1312 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy114,&yymsp[0].minor.yy0);}
#line 3585 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 186: /* expr ::= expr IS NOT NULL */
#line 1313 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy114,&yymsp[0].minor.yy0);}
#line 3590 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 187: /* expr ::= NOT expr */
      case 188: /* expr ::= BITNOT expr */ yytestcase(yyruleno==188);
#line 1335 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy114,pParse,yymsp[-1].major,&yymsp[0].minor.yy114,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3596 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 189: /* expr ::= MINUS expr */
#line 1339 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy114,pParse,TK_UMINUS,&yymsp[0].minor.yy114,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3601 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 190: /* expr ::= PLUS expr */
#line 1341 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy114,pParse,TK_UPLUS,&yymsp[0].minor.yy114,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3606 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 191: /* between_op ::= BETWEEN */
      case 194: /* in_op ::= IN */ yytestcase(yyruleno==194);
#line 1344 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = 0;}
#line 3612 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 193: /* expr ::= expr between_op expr AND expr */
#line 1346 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy114.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy114.pExpr);
  yymsp[-4].minor.yy114.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy114.pExpr, 0);
  if( yymsp[-4].minor.yy114.pExpr ){
    yymsp[-4].minor.yy114.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy150, &yymsp[-4].minor.yy114);
  yymsp[-4].minor.yy114.zEnd = yymsp[0].minor.yy114.zEnd;
}
#line 3628 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 196: /* expr ::= expr in_op LP exprlist RP */
#line 1361 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy266==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy114.pExpr, false);
    int tk = yymsp[-3].minor.yy150 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy114.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy114.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy114.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy266->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy266->a[0].pExpr;
    yymsp[-1].minor.yy266->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy266);
    yymsp[-4].minor.yy114.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy150 ? TK_NE : TK_EQ, yymsp[-4].minor.yy114.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy114.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy114.pExpr, 0);
    if( yymsp[-4].minor.yy114.pExpr ){
      yymsp[-4].minor.yy114.pExpr->x.pList = yymsp[-1].minor.yy266;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy114.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy266);
    }
    exprNot(pParse, yymsp[-3].minor.yy150, &yymsp[-4].minor.yy114);
  }
  yymsp[-4].minor.yy114.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3678 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 197: /* expr ::= LP select RP */
#line 1407 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy114,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy114.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy114.pExpr, yymsp[-1].minor.yy149);
}
#line 3687 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 198: /* expr ::= expr in_op LP select RP */
#line 1412 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy114.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy114.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy114.pExpr, yymsp[-1].minor.yy149);
  exprNot(pParse, yymsp[-3].minor.yy150, &yymsp[-4].minor.yy114);
  yymsp[-4].minor.yy114.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3697 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 199: /* expr ::= expr in_op nm paren_exprlist */
#line 1418 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy266 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy266);
  yymsp[-3].minor.yy114.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy114.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy114.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy150, &yymsp[-3].minor.yy114);
  yymsp[-3].minor.yy114.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3714 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 200: /* expr ::= EXISTS LP select RP */
#line 1431 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy114,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy114.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy149);
}
#line 3724 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 201: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1439 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy114,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy114.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy513, 0);
  if( yymsp[-4].minor.yy114.pExpr ){
    yymsp[-4].minor.yy114.pExpr->x.pList = yymsp[-1].minor.yy20 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy266,yymsp[-1].minor.yy20) : yymsp[-2].minor.yy266;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy114.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy266);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy20, false);
  }
}
#line 3739 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 202: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1452 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy266 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy266, yymsp[-2].minor.yy114.pExpr);
  yymsp[-4].minor.yy266 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy266, yymsp[0].minor.yy114.pExpr);
}
#line 3747 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 203: /* case_exprlist ::= WHEN expr THEN expr */
#line 1456 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy266 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy114.pExpr);
  yymsp[-3].minor.yy266 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy266, yymsp[0].minor.yy114.pExpr);
}
#line 3755 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 207: /* nexprlist ::= nexprlist COMMA expr */
#line 1473 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy266 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy266,yymsp[0].minor.yy114.pExpr);}
#line 3760 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 208: /* nexprlist ::= expr */
#line 1475 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy266 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy114.pExpr); /*A-overwrites-Y*/}
#line 3765 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 210: /* paren_exprlist ::= LP exprlist RP */
      case 215: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==215);
#line 1482 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy266 = yymsp[-1].minor.yy266;}
#line 3771 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 211: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1488 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy266, yymsp[-8].minor.yy150,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy150);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3786 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 212: /* uniqueflag ::= UNIQUE */
#line 1501 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = SQL_INDEX_TYPE_UNIQUE;}
#line 3791 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 213: /* uniqueflag ::= */
#line 1502 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy150 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3796 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 216: /* eidlist ::= eidlist COMMA nm */
#line 1537 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy266 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy266, &yymsp[0].minor.yy0);
}
#line 3803 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 217: /* eidlist ::= nm */
#line 1540 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[0].minor.yy266 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3810 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 218: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1547 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy93, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy150);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 3819 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 219: /* cmd ::= SET SESSION nm EQ term */
#line 1555 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
    sql_setting_set(pParse,&yymsp[-2].minor.yy0,yymsp[0].minor.yy114.pExpr);
}
#line 3826 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 220: /* cmd ::= PRAGMA nm */
#line 1561 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0);
}
#line 3833 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 221: /* cmd ::= PRAGMA nm LP nm RP */
#line 1564 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);
}
#line 3840 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 222: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1567 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0);
}
#line 3847 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 223: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1572 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy359, &all);
}
#line 3858 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 224: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1582 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy93, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy150, yymsp[-4].minor.yy68.a, yymsp[-4].minor.yy68.b, yymsp[0].minor.yy20,
                          yymsp[-7].minor.yy150);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3868 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 225: /* trigger_time ::= BEFORE */
#line 1590 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy150 = TK_BEFORE; }
#line 3873 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 226: /* trigger_time ::= AFTER */
#line 1591 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy150 = TK_AFTER;  }
#line 3878 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 227: /* trigger_time ::= INSTEAD OF */
#line 1592 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy150 = TK_INSTEAD;}
#line 3883 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 228: /* trigger_time ::= */
#line 1593 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[1].minor.yy150 = TK_BEFORE; }
#line 3888 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 229: /* trigger_event ::= DELETE|INSERT */
      case 230: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==230);
#line 1597 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy68.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy68.b = 0;}
#line 3894 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 231: /* trigger_event ::= UPDATE OF idlist */
#line 1599 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[-2].minor.yy68.a = TK_UPDATE; yymsp[-2].minor.yy68.b = yymsp[0].minor.yy520;}
#line 3899 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 232: /* foreach_clause ::= */
#line 1601 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "FOR EACH STATEMENT triggers are not implemented, "
           "please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3909 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 233: /* when_clause ::= */
#line 1611 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[1].minor.yy20 = 0; }
#line 3914 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 234: /* when_clause ::= WHEN expr */
#line 1612 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy20 = yymsp[0].minor.yy114.pExpr; }
#line 3919 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 235: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1616 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy359!=0 );
  yymsp[-2].minor.yy359->pLast->pNext = yymsp[-1].minor.yy359;
  yymsp[-2].minor.yy359->pLast = yymsp[-1].minor.yy359;
}
#line 3928 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 236: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1621 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy359!=0 );
  yymsp[-1].minor.yy359->pLast = yymsp[-1].minor.yy359;
}
#line 3936 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 237: /* trnm ::= nm DOT nm */
#line 1632 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "qualified table names are not allowed on INSERT, "
           "UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3947 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 238: /* tridxby ::= INDEXED BY nm */
#line 1645 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the INDEXED BY clause is not allowed on UPDATE "\
           "or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3957 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 239: /* tridxby ::= NOT INDEXED */
#line 1651 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the NOT INDEXED BY clause is not allowed on "\
           "UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 3967 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 240: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1664 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy359 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy266, yymsp[0].minor.yy20, yymsp[-5].minor.yy150);
     if (yymsp[-6].minor.yy359 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 3978 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 241: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1673 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  /*yylhsminor.yy359-overwrites-yymsp[-4].minor.yy150. */
  yylhsminor.yy359 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy520, yymsp[0].minor.yy149, yymsp[-4].minor.yy150);
  if (yylhsminor.yy359 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3990 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-4].minor.yy359 = yylhsminor.yy359;
        break;
      case 242: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1683 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy359 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy20);
  if (yymsp[-4].minor.yy359 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4002 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 243: /* trigger_cmd ::= select */
#line 1692 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  /* yylhsminor.yy359-overwrites-yymsp[0].minor.yy149. */
  yylhsminor.yy359 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy149);
  if (yylhsminor.yy359 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4014 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy359 = yylhsminor.yy359;
        break;
      case 244: /* expr ::= RAISE LP IGNORE RP */
#line 1702 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy114,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy114.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy114.pExpr ){
    yymsp[-3].minor.yy114.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 4026 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 245: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1709 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy114,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy114.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy114.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy114.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy150;
}
#line 4039 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 246: /* raisetype ::= ROLLBACK */
#line 1720 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 4044 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 247: /* raisetype ::= ABORT */
#line 1721 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = ON_CONFLICT_ACTION_ABORT;}
#line 4049 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 248: /* raisetype ::= FAIL */
#line 1722 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[0].minor.yy150 = ON_CONFLICT_ACTION_FAIL;}
#line 4054 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 249: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1726 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy93, &t, yymsp[-1].minor.yy150);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 4064 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 250: /* alter_table_start ::= ALTER TABLE fullname */
#line 1743 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-2].minor.yy380 = yymsp[0].minor.yy93; }
#line 4069 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 251: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1746 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
   yylhsminor.yy450.table_name = yymsp[-3].minor.yy380;
   yylhsminor.yy450.name = yymsp[0].minor.yy0;
   pParse->initiateTTrans = true;
 }
#line 4078 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-3].minor.yy450 = yylhsminor.yy450;
        break;
      case 252: /* alter_add_column ::= alter_table_start ADD column_name */
#line 1753 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yylhsminor.yy450.table_name = yymsp[-2].minor.yy380;
  yylhsminor.yy450.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 4088 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[-2].minor.yy450 = yylhsminor.yy450;
        break;
      case 253: /* column_name ::= COLUMN nm */
#line 1759 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4094 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 254: /* column_name ::= nm */
#line 1760 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yylhsminor.yy0 = yymsp[0].minor.yy0; }
#line 4099 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 255: /* alter_column_def ::= alter_add_column typedef */
#line 1764 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, yymsp[-1].minor.yy450.table_name, &yymsp[-1].minor.yy450.name, &yymsp[0].minor.yy122);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  sql_create_column_start(pParse);
}
#line 4110 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 256: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1772 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy450.table_name, &yymsp[-11].minor.yy450.name, yymsp[-7].minor.yy266, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy266,
                     yymsp[-2].minor.yy150, yymsp[-1].minor.yy150, yymsp[0].minor.yy150);
  sql_create_foreign_key(pParse);
}
#line 4119 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 257: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1778 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy450.table_name, &yymsp[-4].minor.yy450.name, &yymsp[-1].minor.yy114);
    sql_create_check_contraint(pParse);
}
#line 4127 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 258: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1783 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy450.table_name, &yymsp[-4].minor.yy450.name, yymsp[-1].minor.yy266, yymsp[-3].minor.yy150,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4136 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 259: /* unique_spec ::= UNIQUE */
#line 1790 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy150 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4141 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 260: /* unique_spec ::= PRIMARY KEY */
#line 1791 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy150 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4146 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 261: /* cmd ::= alter_table_start RENAME TO nm */
#line 1793 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy380, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4155 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 262: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1799 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  drop_constraint_def_init(&pParse->drop_constraint_def, yymsp[-3].minor.yy93, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_constraint(pParse);
}
#line 4164 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 263: /* cmd ::= alter_table_start enable CHECK CONSTRAINT nm */
#line 1805 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
    enable_entity_def_init(&pParse->enable_entity_def, ENTITY_TYPE_CK, yymsp[-4].minor.yy380,
                           &yymsp[0].minor.yy0, yymsp[-3].minor.yy295);
    sql_alter_ck_constraint_enable(pParse);
}
#line 4173 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 264: /* with ::= */
#line 1817 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{yymsp[1].minor.yy473 = 0;}
#line 4178 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 265: /* with ::= WITH wqlist */
#line 1818 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-1].minor.yy473 = yymsp[0].minor.yy473; }
#line 4183 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 266: /* with ::= WITH RECURSIVE wqlist */
#line 1819 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[-2].minor.yy473 = yymsp[0].minor.yy473; }
#line 4188 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 267: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1821 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy473 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy266, yymsp[-1].minor.yy149); /*A-overwrites-X*/
}
#line 4195 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 268: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1824 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy473 = sqlWithAdd(pParse, yymsp[-7].minor.yy473, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy266, yymsp[-1].minor.yy149);
}
#line 4202 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 269: /* typedef ::= TEXT */
      case 270: /* typedef ::= STRING_KW */ yytestcase(yyruleno==270);
#line 1830 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy122.type = FIELD_TYPE_STRING; }
#line 4208 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 271: /* typedef ::= SCALAR */
#line 1832 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy122.type = FIELD_TYPE_SCALAR; }
#line 4213 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 272: /* typedef ::= BOOL */
      case 273: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==273);
#line 1834 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy122.type = FIELD_TYPE_BOOLEAN; }
#line 4219 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 274: /* typedef ::= VARBINARY */
#line 1836 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy122.type = FIELD_TYPE_VARBINARY; }
#line 4224 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 275: /* char_len ::= LP INTEGER RP */
#line 1848 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy150;
  (void) yymsp[-1].minor.yy0;
}
#line 4232 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 276: /* typedef ::= VARCHAR char_len */
#line 1854 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy122.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy150;
}
#line 4240 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 277: /* number_typedef ::= NUMBER */
#line 1861 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy122.type = FIELD_TYPE_NUMBER; }
#line 4245 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 278: /* number_typedef ::= DOUBLE */
#line 1862 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy122.type = FIELD_TYPE_DOUBLE; }
#line 4250 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 279: /* number_typedef ::= INT|INTEGER_KW */
#line 1863 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy122.type = FIELD_TYPE_INTEGER; }
#line 4255 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      case 280: /* number_typedef ::= UNSIGNED */
#line 1864 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"
{ yymsp[0].minor.yy122.type = FIELD_TYPE_UNSIGNED; }
#line 4260 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
        break;
      default:
      /* (281) input ::= ecmd */ yytestcase(yyruleno==281);
      /* (282) explain ::= */ yytestcase(yyruleno==282);
      /* (283) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=283);
      /* (284) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==284);
      /* (285) savepoint_opt ::= */ yytestcase(yyruleno==285);
      /* (286) cmd ::= create_table create_table_args with_opts create_table_end */ yytestcase(yyruleno==286);
      /* (287) create_table_args ::= LP columnlist RP */ yytestcase(yyruleno==287);
      /* (288) with_opts ::= WITH engine_opts */ yytestcase(yyruleno==288);
      /* (289) with_opts ::= */ yytestcase(yyruleno==289);
      /* (290) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==290);
      /* (291) columnlist ::= columnlist COMMA column_def create_column_end */ yytestcase(yyruleno==291);
      /* (292) columnlist ::= column_def create_column_end */ yytestcase(yyruleno==292);
      /* (293) column_def ::= column_name_and_type carglist */ yytestcase(yyruleno==293);
      /* (294) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=294);
      /* (295) carglist ::= carglist ccons */ yytestcase(yyruleno==295);
      /* (296) carglist ::= */ yytestcase(yyruleno==296);
      /* (297) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=297);
      /* (298) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=298);
      /* (299) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=299);
      /* (300) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=300);
      /* (301) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=301);
      /* (302) oneselect ::= values */ yytestcase(yyruleno==302);
      /* (303) sclp ::= selcollist COMMA */ yytestcase(yyruleno==303);
      /* (304) as ::= ID|STRING */ yytestcase(yyruleno==304);
      /* (305) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==305);
      /* (306) join_nm ::= JOIN_KW */ yytestcase(yyruleno==306);
      /* (307) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=307);
      /* (308) type_func ::= CHAR */ yytestcase(yyruleno==308);
      /* (309) exprlist ::= nexprlist */ yytestcase(yyruleno==309);
      /* (310) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==310);
      /* (311) trnm ::= nm */ yytestcase(yyruleno==311);
      /* (312) tridxby ::= */ yytestcase(yyruleno==312);
      /* (313) cmd ::= alter_column_def carglist create_column_end */ yytestcase(yyruleno==313);
      /* (314) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=314);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, TOKEN.n, TOKEN.z, TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, TOKEN.n,
             TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4365 "/build/usr/src/debug/tarantool-2.7.2.195/src/box/sql/parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
